/************************************************************************************//**
* \file         Demo/ARMCM7_STM32F7_Maximatecc_IAR/Prog/shared_params.h
* \brief        Shared RAM parameters header file.
* \ingroup      Prog_ARMCM7_STM32F7_Maximatecc_IAR
* \internal
*----------------------------------------------------------------------------------------
*                          C O P Y R I G H T
*----------------------------------------------------------------------------------------
*   Copyright (c) 2020  by Feaser    http://www.feaser.com    All rights reserved
*
*----------------------------------------------------------------------------------------
*                            L I C E N S E
*----------------------------------------------------------------------------------------
* This file is part of OpenBLT. It is released under a commercial license. Refer to
* the license.pdf file for the exact licensing terms. It should be located in
* '.\Doc\license.pdf'. Contact Feaser if you did not receive the license.pdf file.
* 
* In a nutshell, you are allowed to modify and use this software in your closed source
* proprietary application, provided that the following conditions are met:
* 1. The software is not released or distributed in source (human-readable) form.
* 2. These licensing terms and the copyright notice above are not changed.
* 
* This software has been carefully tested, but is not guaranteed for any particular
* purpose. Feaser does not offer any warranties and does not guarantee the accuracy,
* adequacy, or completeness of the software and is not responsible for any errors or
* omissions or the results obtained from use of the software.
*
* \endinternal
****************************************************************************************/
#ifndef SHARED_PARAMS_H
#define SHARED_PARAMS_H

/****************************************************************************************
* Include files
****************************************************************************************/
#include <stdint.h>                                    /* Standard integer types.      */
#include <stdbool.h>                                   /* Standard boolean types.      */


/****************************************************************************************
* Configuration macros
****************************************************************************************/
/** \brief Configuration macro for specifying the size of the data inside the parameter
 *         buffer. This is the length in bytes of the actual parameter data, so
 *         excluding the bufferId and checksum.
 */
#define SHARED_PARAMS_CFG_BUFFER_DATA_LEN        (56u)


/****************************************************************************************
* Function prototypes
****************************************************************************************/
void SharedParamsInit(void);
bool SharedParamsReadByIndex(uint32_t idx, uint8_t * value);
bool SharedParamsWriteByIndex(uint32_t idx, uint8_t value);


#endif /* SHARED_PARAMS_H */
/*********************************** end of shared_params.h ****************************/
