/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : EEPROM_Platformservice.h
   Author             : Rajesh
   Version            : V0.0.0.1
   Origination Date   : 04/03/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the EEPROM platform service declarations

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             04/03/2022			Rajesh

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _EEPROM_PLATFORM_SERVICE_H_
#define	_EEPROM_PLATFORM_SERVICE_H_

/* USER CODE BEGIN Macros */

#define EEPROM_SIZE (64 * 1024)

/* USER CODE END Macros */

/*!
 * EEPROM TxQ and RxQ size for
 * sending and receiving data from SDK API.
 */
#define EE_RX_TX_MAX_Q_SIZE     		10

/*!
 * EEPROM Placeholder Min and Max location
 */
#define EE_MIN_PH              			0
#define EE_MAX_PH     		        	SIZE_OF_PLACEHOLDER

/*!
 * EEPROM Platform Service Task Size
 */
#define EE_TASK_SIZE         			512

/* !
 * EEPROM SDK Field Index
 */
#define EE_FUNC_INDEX             		0
#define EE_RESULT_INDEX           		0
#define EE_PH_ID_INDEX                  1
#define EE_PH_DATA_INDEX                2
#define EE_PH_LEN_INDEX                 3



/*!
 * EEPROM Enable /
 * EEPROM disable
 */
#define   EE_ENABLE          			1
#define   EE_DISABLE         			0

/*!
 * EEPROM Events
 */
typedef enum __EE_Event
{
	EE_TMR_EVENT,
	EE_MSG_EVENT,
}EE_Event;


/*!
 * EEPROM SDK Message
 */
typedef enum __EE_MSG
{
	EE_GET,
	EE_SET,
}EE_MSG;


/*!
 * Return Error value
 */
#define   INVALID_EE_DATA    			-1

/*!
 * Return Valid data
 */
#define   VALID_EE_DATA       			1

/*!
 * Return the updated with default value
 */
#define   VALID_EE_DEFAULT    			2

/*!
 * EEPROM Write failure retry
 */
#define EEPROM_FAILURE_RETRY            3

/*!
 * Copying the EEPROM data for verifying the data
 */
#define EEPROM_SDRAM_ADDRESS            0x20000040 //0xC0180000	//0x30041000
#define EEPROM_SHADOW_ADDRESS           0x20000240 //0xC0190000	//0x38000000

/*!
 * EEPROM Magic number stored in the EEPROM
 */
#define EEPROM_MAGIC_NUMBER  			0xAC2EAC2E

/*!
 * EEPROM Magic number size
 */
#define MAGIC_NUMBER_SIZE    			4

/*!
 * Function declaration
 */
void Init_Shadow_memory();
void EEPROM_DB_Init(void);
int8_t Get_placeholderdata(uint16_t placeholder, uint8_t *eeprom_data);

#endif	//_EEPROM_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
