/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : Qspi.h
   Author             : Adrush
   Version            : V0.0.0.1
   Origination Date   : 21/01/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the Qspi macro information

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             21/01/2022           Adrush

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _QSPI_H_
#define	_QSPI_H_


/*****************************************************************************
 *
 *                      QSPI Module
 *
 *****************************************************************************/

/*!
 * QSPI SDK API (PS_ENABLE) / Disable(PS_DISABLE) Macros
 */
#define SDK_SERVICE_QSPI      			 		 PS_ENABLE

#if (SDK_SERVICE_QSPI == PS_ENABLE)

/*
 * QSPI_MEMORY_MODE      		INDIRECT_MODE
 *                       		MAPPED_MODE
 */
#define QSPI_MEMORY_MODE						 MAPPED_MODE
#endif

//	QSPI Error codes
#define QSPI_OK            ((uint8_t)0x00)
#define QSPI_ERROR         ((uint8_t)0x01)
#define QSPI_BUSY          ((uint8_t)0x02)
#define QSPI_NOT_SUPPORTED ((uint8_t)0x04)
#define QSPI_SUSPENDED     ((uint8_t)0x08)

#define INDIRECT_MODE		0
#define MAPPED_MODE			1

//#define FLASH_SIZE                  0x2000000
#define SECTOR_SIZE                 0x10000
#define SUBSECTOR_SIZE              0x1000
#define PAGE_SIZE                   0x100

#define RESET_ENABLE_CMD                     0x66
#define RESET_MEMORY_CMD                     0x99

#define BULK_ERASE_MAX_TIME         50000
#define SECTOR_ERASE_MAX_TIME       2000
#define SUBSECTOR_ERASE_MAX_TIME    400
  // Winbond specific commands
//        static constexpr uint8_t ENTER_QUAD_MODE = 0x38;
//        static constexpr uint8_t SET_READ_PARAMETERS = 0xC0;
//    { winbondFlashClass::W25Q32, 0x4016,4194304, 16384,1024,64  },
/*
 * MANUFACTURER AND DEVICE IDENTIFICATION
 *
 * MANUFACTURER ID				(MF7-MF0)
 * WINDBOND SERIAL FLASH		EF
 *
 * DEVICE ID					(ID7-ID0)				(ID15-ID0)
 * INSTRUCTION					0XAB,0X90,0X92,0X94		 0X9F
 * W25Q32JV						0X15					 0X4016
 *
 *
 */
/*
 * Power - Up Power Down timing requirements refrence datasheet:
 * VCC(min) to /CS Low 20us
 * Time Delay Before Write Instruction 5ms
 *
 * WARNING	: If the IO2 or IO3 pins are tied directly to the power supply or ground
 * during statndard SPI or DUAL SPI operation, the QE bit should never be set to a 1.
 */
/*
 * Instruction Set Table 1 (Standard SPI instruccions)
 */
#define W25Q32JV_WRITE_ENABLE_INSTRUCTION 				0x06
#define W25Q32JV_VOLATILE_SR_WRITE_ENABLE_INSTRUCTION 	0x50//------------------IMPLEMENT!
#define W25Q32JV_WRITE_DISABLE_INSTRUCTION 				0x04

#define W25Q32JV_RELEASE_POWER_DOWN_ID_INSTRUCTION		0xAB//-------------------IMPLEMENT!
#define W25Q32JV_MANUFACTURER_DEVICE_ID_INSTRUCTION 	0x90//-------------------IMPLEMENT!
#define W25Q32JV_JEDEC_ID_INSTRUCTION			 		0x9F//-------------------IMPLEMENT!
#define W25Q32JV_READ_UNIQUE_ID_INSTRUCTION 			0x4B//-------------------IMPLEMENT!

#define W25Q32JV_READ_DATA_INSTRUCTION					0x03//-------------------IMPLEMENT!
#define W25Q32JV_FAST_READ_INSTRUCTION 					0x0B//-------------------IMPLEMENT!
#define W25Q32JV_PAGE_PROGRAM_INSTRUCTION			 	0x02//-------------------IMPLEMENT!
#define W25Q32JV_SECTOR_ERASE_4KB_INSTRUCTION			0x20//-------------------IMPLEMENT!
#define W25Q32JV_BLOCK_ERASE_32KB_INSTRUCTION			0x52//-------------------IMPLEMENT!
#define W25Q32JV_BLOCK_ERASE_64KB_INSTRUCTION			0xD8//-------------------IMPLEMENT!
#define W25Q32JV_CHIP_ERASE_1_INSTRUCTION				0xC7//-------------------IMPLEMENT!
#define W25Q32JV_CHIP_ERASE_2_INSTRUCTION				0x60//-------------------IMPLEMENT!
#define W25Q32JV_READ_STATUS_REGISTER1_INSTRUCTION		0x05
#define W25Q32JV_WRITE_STATUS_REGISTER1_INSTRUCTION		0X01//-------------------IMPLEMENT!


//The Quad Enable bit QE of Status Register-2 must be set to enable the Fast Read Quad I/O Instruction.

#define W25Q32JV_READ_STATUS_REGISTER2_INSTRUCTION		0X35//-------------IMPLEMENT!
#define W25Q32JV_WRITE_STATUS_REGISTER2_INSTRUCTION		0X31//-------------IMPLEMENT!


#define W25Q32JV_READ_STATUS_REGISTER3_INSTRUCTION		0X15//-------------IMPLEMENT!
#define W25Q32JV_WRITE_STATUS_REGISTER3_INSTRUCTION		0X11//-------------IMPLEMENT!

#define W25Q32JV_READ_STATUS_REGISTER3_INSTRUCTION		0X15
#define W25Q32JV_WRITE_STATUS_REGISTER3_INSTRUCTION		0X11

#define W25Q32JV_READ_SFDP_REGISTER_INSTRUCTION			0X5A
#define W25Q32JV_ERASE_SECURITY_REGISTER_INSTRUCTION	0X44
#define W25Q32JV_PROGRAM_SECURITY_REGISTER_INSTRUCTION	0X42
#define W25Q32JV_READ_SECURITY_REGISTER_INSTRUCTION		0X48
#define W25Q32JV_GLOBAL_BLOCK_LOCK_INSTRUCTION			0X7E
#define W25Q32JV_GLOBAL_BLOCK_UNLOCK_INSTRUCTION		0X98
#define W25Q32JV_GLOBAL_READ_BLOCK_LOCK_INSTRUCTION		0X3D
#define W25Q32JV_INDIVIDUAL_BLOCK_LOCK_INSTRUCTION		0X36
#define W25Q32JV_INDIVIDUAL_BLOCK_UNLOCK_INSTRUCTION	0X39
#define W25Q32JV_ERASE_PROGRAM_SUSPEND_INSTRUCTION		0X75//-------------------IMPLEMENT!
#define W25Q32JV_ERASE_PROGRAM_RESUME_INSTRUCTION		0X7A//-------------------IMPLEMENT!
#define W25Q32JV_POWER_DOWN_INSTRUCTION					0XB9//-------------------IMPLEMENT!
#define W25Q32JV_ENABLE_RESET_INSTRUCTION				0X66
#define W25Q32JV_RESET_DEVICE_INSTRUCTION				0X99

/*
 * Instruction Set Table 2 (DUAL/QUAP SPI instruccions)
 */

#define W25Q32JV_FAST_READ_DUAL_OUTPUT_INSTRUCTION		0X3B
#define W25Q32JV_FAST_READ_DUAL_I_O_INSTRUCTION			0XBB
#define W25Q32JV_MFTR_DEVICE_ID_DUAL_I_O_INSTRUCTION	0X92

#define W25Q32JV_QUAD_INPUT_PAGE_PROGRAM_INSTRUCTION	0X32//------IMPLEMENT!
#define W25Q32JV_FAST_READ_QUAD_OUTPUT_INSTRUCTION		0X6B
#define W25Q32JV_MFTR_DEVICE_ID_QUAD_I_O_INSTRUCTION	0X94

#define W25Q32JV_FAST_READ_QUAD_I_O_INSTRUCTION			0XEB
#define W25Q32JV_SET_BURST_WITH_WRAP_INSTRUCTION		0X77

uint8_t QSPI_ResetMemory(QSPI_HandleTypeDef *hqspi);
uint8_t QSPI_WriteEnable(QSPI_HandleTypeDef *hqspi);
uint8_t QSPI_Erase_Block(uint32_t BlockAddress);
uint8_t QSPI_Write(uint8_t* pData, uint32_t WriteAddr, uint32_t Size);
uint8_t QSPI_Read(uint8_t* pData, uint32_t ReadAddr, uint32_t Size);
uint8_t QSPI_AutoPollingMemReady(QSPI_HandleTypeDef *hqspi, uint32_t Timeout);
uint8_t QSPI_selfTest(QSPI_HandleTypeDef *hqspi, unsigned long int size, unsigned long int location);
uint8_t QSPI_EnableMemoryMappedMode(QSPI_HandleTypeDef *hqspi);
void QSPI_QuadEnableCfg(QSPI_HandleTypeDef *hqspi);

#endif	//_QSPI_H_
