/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : SWTimer_platformservice.h
   Author             :	Adrush
   Version            : V0.0.0.1
   Origination Date   : 04/03/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the SWTimer platform service declaration

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             04/03/2022			Adrush

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _SWTIMER_PLATFORM_SERVICE_H_
#define	_SWTIMER_PLATFORM_SERVICE_H_

/*!
 * SWTimer TX Q size for
 * receiving data from SDK API.
 */
#define SWT_RX_TX_MAX_Q_SIZE 		10

/*!
 * SWTimer Platform service Task timeout value
 */
#define PS_SWT_SECOND_TIMEOUT       1000

/*!
 * SET SWTimer Parameter
 */
#define SET_SWT_PARAMETER			1

/*!
 * SWTimer parameter max and min value
 */
#define SWT_MIN_MS					1
#define SWT_MAX_MS					60000

#define SWTBUF_BUF_SIZE				9

/*!
 * SWTimer Task stack Depth
 */
#define SWT_STACK_DEPTH				512

/* !
 * SWTimer SDK Field Index
 */
#define SWT_FUNC_INDEX             	0
#define SWT_RESULT_INDEX           	0
#define SWT_COUNT_INDEX          	1
#define SWT_STATUS_INDEX            2
#define SWT_MODE_INDEX             	3
#define SWT_TIMEMS_INDEX          	4

/*!
 * SWTimer SDK Message
 */
typedef enum __SWT_MSG
{
	SWT_SET,
	SWT_GET,

}SWT_MSG;

/*!
 * SWTimer Input Events
 */
typedef enum __SWT_Event
{
	SWT_TMR_EVENT,
	SWT1_OCCURED,
	SWT2_OCCURED,
	SWT3_OCCURED,
	SWT4_OCCURED,
	SWT5_OCCURED,
	SWT6_OCCURED,
	SWT_MSG_EVENT,
}SWT_Event;


/*!
 * SWTimer Input Events
 */
typedef enum __SWT_Count
{
	SWT1=1,
	SWT2,
	SWT3,
	SWT4,
	SWT5,
	SWT6,
}SWT_Count;

/*!
 * SWTimer Input Function
 */
typedef enum __SWT_Func
{
	SW_TIME,
	SW_ALARM_A,
	SW_ALARM_B,
}SWT_Func;

/*!
 * SWTIMER DB Values
 */
typedef enum __SWT_DB_Value
{
	SWT_ACTIVE = 1,
	SWT_INACTIVE,
}SWT_DB_Value;

/*!
 * SWTIMER DB Values
 */
typedef enum __SWT_DB_Mode
{
	SWT_ONESHOT,
	SWT_CONTINUOUS,
}SWT_DB_Mode;

/*!
 * SWTIMER callback status
 */
typedef enum __SWT_callback_status
{
	CALLBACK_CLEAR,
	CALLBACK_OCCURED,
}SWT_callback_status;


/*!
 * Function declaration
 */
void SWT_PS_DB_Init(void);
void PS_TIM4_Init(void);
void PS_TIM7_Init(void);
void PS_TIM8_Init(void);
void PS_TIM12_Init(void);
void PS_TIM17_Init(void);
void PS_TIM16_Init(void);
void clear_timer_callback(uint16_t db_idx);
void SWTimer_Callback_1();
void SWTimer_Callback_2();
void SWTimer_Callback_3();
void SWTimer_Callback_4();
void SWTimer_Callback_5();
void SWTimer_Callback_6();

#endif	//_SWTimer_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
