/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : data_layer.c
   Author             : Jonathan Serrano
   Version            : V0.0.0.1
   Origination Date   : 21/01/2022
   Description        : C Source File.
   Environment        : Independant
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

		General File Description
-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.0             06/25/2020           Jonathan Serrano
   0.0.0.1             21/01/2022           Rajesh

   Notes:              - Initial Version
-----------------------------------------------------------------------------
 *****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
 ****************************************************************************/
/* Includes ---------------------------------------------------------------*/
#include "../inc/Data_Layer.h"

#include "../Inc/Common.h"

/* USER CODE BEGIN PD */
/* USER CODE END PD */

/* USER CODE BEGIN PV */
static uint8_t  dl_u8      [(END_U8BIT      -1)  - START_U8BIT   ];
static uint16_t dl_u16     [(END_U16BIT     -1)  - START_U16BIT  ];
static uint32_t dl_u32     [(END_U32BIT     -1)  - START_U32BIT  ];
static uint64_t dl_u64     [(END_U64BIT     -1)  - START_U64BIT  ];
static int8_t   dl_s8      [(END_S8BIT      -1)  - START_S8BIT   ];
static int16_t  dl_s16     [(END_S16BIT     -1)  - START_S16BIT  ];
static int32_t  dl_s32     [(END_S32BIT     -1)  - START_S32BIT  ];
static float    dl_float   [(END_FLOAT      -1)  - START_FLOAT   ];
//static uint32_t dl_eeprom  [(END_EEPROM     -1)  - START_EEPROM  ];
int8_t   dl_buf     [((END_BUF512BIT -1)  - START_BUF512BIT) * DB_512BIT_NO_BUF * BUF512BITSIZE];

/* J1939 DB Buffers */
uint8_t   dl_ju8      [(END_J1939U8BIT      -1)   - START_J1939U8BIT    ];
uint16_t  dl_ju16     [(END_J1939U16BIT     -1)   - START_J1939U16BIT   ];
uint32_t  dl_ju32     [(END_J1939U32BIT     -1)   - START_J1939U32BIT   ];

extern int8_t (*dl_u8_func     [(END_U8BIT     -1) - START_U8BIT     ])(uint16_t, uint8_t);
extern int8_t (*dl_u16_func    [(END_U16BIT    -1) - START_U16BIT    ])(uint16_t, uint16_t);
extern int8_t (*dl_u32_func    [(END_U32BIT    -1) - START_U32BIT    ])(uint16_t, uint32_t);
extern int8_t (*dl_u64_func    [(END_U64BIT    -1) - START_U64BIT    ])();
extern int8_t (*dl_s8_func     [(END_S8BIT     -1) - START_S8BIT     ])();
extern int8_t (*dl_s16_func    [(END_S16BIT    -1) - START_S16BIT    ])();
extern int8_t (*dl_s32_func    [(END_S32BIT    -1) - START_S32BIT    ])();
extern int8_t (*dl_float_func  [(END_FLOAT     -1) - START_FLOAT     ])(uint16_t, float);
//extern int8_t (*dl_eeprom_func [(END_EEPROM    -1) - START_EEPROM    ])(uint16_t, uint8_t*);
extern int8_t (*dl_buf_func    [(END_BUF512BIT -1) - START_BUF512BIT ])(uint16_t, uint8_t*);
extern int8_t (*dl_ju8_func    [(END_J1939U8BIT -1) - START_J1939U8BIT])(uint16_t, uint8_t);
extern int8_t (*dl_ju16_func   [(END_J1939U16BIT -1) - START_J1939U16BIT])(uint16_t, uint16_t);
extern int8_t (*dl_ju32_func   [(END_J1939U32BIT -1) - START_J1939U32BIT])(uint16_t, uint32_t);
/* USER CODE END PV */

/* USER CODE BEGIN PFP */
uint8_t Get_data_type(uint16_t dl_index);
static uint16_t Get_Element_idx(uint32_t dl_index);
extern int8_t validate_placeholder(uint16_t placeholder, uint8_t *eeprom_data);
/* USER CODE END PFP */

/**************** (C) COPYRIGHT 2020 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/

/** @brief Get_DL
 *
 *  This function will get the data from the platform service
 *
 *  @param  dl_index[IN]   : DB index value
 *  		buf[IN]		   : input buffer
 *
 *  @return  0 : FAILURE
 *  		 1 : SUCCESS
 *  		-3 : NULL_POINTER
 *
 */
int8_t Get_DL(uint16_t dl_index, uint8_t *buf)
{
	uint8_t data_type = NOT_SUPPRTED;
	volatile uint64_t value = 0;
	uint16_t internal_Idx = NOT_VALID_IDX;

#if((SDK_SERVICE_EEPROM == PS_ENABLE) || (SDK_SERVICE_FDCAN == PS_ENABLE))
	int8_t  res = FAILURE;
#endif

	/* Check for the Null pointer */
	if (NULL == buf)
		return NULL_POINTER;

	data_type = Get_data_type(dl_index);
	internal_Idx = Get_Element_idx(dl_index);

	/*Get pointer array according to the size*/

	switch(data_type)
	{
	case DLU8:
		/* Copy the data to the user buffer */
		buf[0] = dl_u8[internal_Idx];

#if (SDK_SERVICE_SWTIMER == PS_ENABLE)
		clear_timer_callback(dl_index);
#endif
		break;

	case DLU16:
		/* Copy the data to the user buffer */
		memcpy(&buf[0], &dl_u16[internal_Idx],sizeof(uint16_t));
		break;

	case DLU32:
		/* Copy the data to the user buffer */
		memcpy(&buf[0], &dl_u32[internal_Idx],sizeof(uint32_t));
		break;

	case DLU64:
		value = dl_u64[internal_Idx];
		break;
	case DLS8:
		value = dl_s8[internal_Idx];
		break;
	case DLS16:
		value = dl_s16[internal_Idx];
		break;
	case DLS32:
		value = dl_s32[internal_Idx];
		break;
	case DLFLOAT:
		memcpy(&buf[0], &dl_float[internal_Idx],sizeof(float));
		break;
	case DL_EEPROM:

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
		/* Get the Place Holder data from EEPROM PS */
		res = Get_placeholderdata(internal_Idx, (uint8_t *)buf);

		if (FAILURE == res)
			data_type = NOT_SUPPRTED;
#endif

		break;
	case DL_BUF512BIT:

		/* Copy the data to the USER Buffer */
		memcpy(buf, &dl_buf[internal_Idx * BUF512BITSIZE], BUF512BITSIZE);

#if (SDK_SERVICE_FDCAN == PS_ENABLE)

		switch(dl_index)
		{
			case CAN0_RX_DATA:
#if (FDCAN1_ENABLE == PS_ENABLE)
				get_can1_data_from_rxbufq(buf);
#endif
				break;

			case CAN1_RX_DATA:
#if (FDCAN2_ENABLE == PS_ENABLE)
				get_can2_data_from_rxbufq(buf);
#endif
				break;
		}
#endif
		break;
	case DL_JU8:
		/* Copy the data to the user buffer */
		//buf[0] = dl_ju8[internal_Idx];
		memcpy(&buf[0], &dl_ju8[internal_Idx], sizeof(uint8_t));
		break;
	case DL_JU16:
		/* Copy the data to the user buffer */
		//buf[0] = dl_ju16[internal_Idx];
		memcpy(&buf[0], &dl_ju16[internal_Idx], sizeof(uint16_t));
		break;
	case DL_JU32:
		/* Copy the data to the user buffer */
		//buf[0] = dl_ju32[internal_Idx];
		memcpy(&buf[0], &dl_ju32[internal_Idx], sizeof(uint32_t));
		break;
		break;
	case NOT_SUPPRTED:
		/* Removing the warnings */
		internal_Idx = value;
		/*Do nothing*/
		break;
	}

	if(data_type == NOT_SUPPRTED)
		return FAILURE;
	else
		return SUCCESS;
}

/** @brief Set_DL
 *
 *  This function will Set the data to the platform service
 *
 *  @param  dl_index[IN]   : DB index value
 *  		buf[IN]		   : input buffer
 *
 *  @return  0 : FAILURE
 *  		 1 : SUCCESS
 *          -3 : NULL_POINTER
 *
 */
int8_t Set_DL(uint16_t dl_index, uint8_t *buf)
{
	uint8_t  data_type    = NOT_SUPPRTED;
	uint16_t internal_Idx = NOT_VALID_IDX;
	int8_t   res = FAILURE;
	int16_t  u16val;
	int16_t  u32val;
	float **float_pointer = 0;
	float float_value = 0;

	/* Check for the Null pointer */
	if (NULL == buf)
		return NULL_POINTER;

	data_type    = Get_data_type(dl_index);
	internal_Idx = Get_Element_idx(dl_index);

	switch(data_type)
	{
		case DLU8:

			/* Validate the field */
			if (NULL == *dl_u8_func[internal_Idx])
				break;

			res = (*dl_u8_func[internal_Idx])(internal_Idx  ,(uint8_t)buf[0]);

			if(SUCCESS == res)
			{
				dl_u8[internal_Idx]     = (uint8_t)buf[0];
			}
			break;

		case DLU16:

			/* Validate the field */
			if (NULL == *dl_u16_func[internal_Idx])
				break;

			u16val = (uint16_t)((buf[1] << 8) | buf[0]);
			res = (*dl_u16_func[internal_Idx])(internal_Idx , u16val);

			if(SUCCESS == res)
			{
				memcpy(&dl_u16[internal_Idx], &buf[0] ,sizeof(uint16_t));
			}
			break;

		case DLU32:

			/* Validate the field */
			if (NULL == *dl_u32_func[internal_Idx])
				break;

			u32val = (int32_t)((buf[3] << 24) | (buf[2] << 16) | (buf[1] << 8) | (buf[0]));
			res = (*dl_u32_func[internal_Idx])(internal_Idx , u32val);

			if(SUCCESS == res)
			{
				memcpy(&dl_u32[internal_Idx], &buf[0] ,sizeof(uint32_t));
			}
			break;

		case DLFLOAT:

			/* Validate the field */
			if (NULL == *dl_float_func[internal_Idx])
				break;

			float_pointer = (float **) &buf;
			float_value = **float_pointer;

			res = (*dl_float_func[internal_Idx])(internal_Idx ,float_value);

			if(SUCCESS == res)
			{
				memcpy(&dl_float[internal_Idx], &float_value ,sizeof(float));
			}
			break;

		case DL_EEPROM:
#if 0
			/* Validate the field */
			if (NULL == *dl_eeprom_func[internal_Idx])
				break;

			res = (*dl_eeprom_func[0])(internal_Idx  ,buf);
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
		/* Get the Place Holder data from EEPROM PS */
		res = validate_placeholder(internal_Idx, (uint8_t *)buf);

		if (FAILURE == res)
			data_type = NOT_SUPPRTED;
#endif
			break;

		case DL_BUF512BIT:

			/* Validate the NULL Parameter */
			if( NULL == buf)
				break;

			switch(dl_index)
			{
#if (SDK_SERVICE_USB == PS_ENABLE)
			uint8_t  val;

				case USB_TX_DATA:

					/* Copy the data into the internal buffer */
					memcpy(&dl_buf[internal_Idx * BUF512BITSIZE], buf, BUF512BITSIZE);

					val = FULL;
					/*set the USB tx buffer status */
					Set_DL(USB_TX_BUFFER_STATUS , (uint8_t *)&val);

					val = TRUE;
					/*set the USB tx data */
					Set_DL(USB_TX_STATUS , (uint8_t *)&val);

					/* Send the data to the USB PS */
					SetUSB(&dl_buf[internal_Idx * BUF512BITSIZE], BUF512BITSIZE);

					val = NO_FULL;
					/*set the USB tx buffer status */
					Set_DL(USB_TX_BUFFER_STATUS , (uint8_t *)&val);

					val = FALSE;
					/*set the USB tx data */
					Set_DL(USB_TX_STATUS , (uint8_t *)&val);
					break;

				case USB_RX_DATA:

					/* Copy the data into the DB buffer */
					memcpy(&dl_buf[internal_Idx * BUF512BITSIZE], buf, BUF512BITSIZE);

					break;
#endif

#if (SDK_SERVICE_BLE == PS_ENABLE)
				case BLE_TX_DATA:

					/* Copy the data into the internal buffer */
					memcpy(&dl_buf[internal_Idx * BUF512BITSIZE], buf, BUF512BITSIZE);

					/* Send the data to the USB PS */
					SetBLE(&dl_buf[internal_Idx * BUF512BITSIZE], BUF512BITSIZE);

					break;

				case BLE_RX_DATA:

					/* Copy the data into the DB buffer */
					memcpy(&dl_buf[internal_Idx * BUF512BITSIZE], buf, BUF512BITSIZE);

					break;
#endif

#if (SDK_SERVICE_FDCAN == PS_ENABLE)
				case CAN0_TX_DATA:

					/* Copy the data into the internal buffer */
					memcpy(&dl_buf[internal_Idx * BUF512BITSIZE], buf, BUF512BITSIZE);

					/* Send the data to the CAN PS */
					SetCAN(FDCAN_1, (uint8_t *)&dl_buf[internal_Idx * BUF512BITSIZE], BUF512BITSIZE);
					break;

				case CAN1_TX_DATA:

					/* Copy the data into the internal buffer */
					memcpy(&dl_buf[internal_Idx * BUF512BITSIZE], buf, BUF512BITSIZE);

					/* Send the data to the CAN PS */
					SetCAN(FDCAN_2, (uint8_t *)&dl_buf[internal_Idx * BUF512BITSIZE], BUF512BITSIZE);

					break;
#endif
				default:
					break;
			}

			case DL_JU8:

				/* Validate the field */
				if (NULL == *dl_ju8_func[internal_Idx])
					break;

				res = (*dl_ju8_func[internal_Idx])(internal_Idx  ,(uint8_t)buf[0]);

				if(SUCCESS == res)
				{
					dl_ju8[internal_Idx]     = (uint8_t)buf[0];
				}

				break;
			case DL_JU16:

				/* Validate the field */
				if (NULL == *dl_ju16_func[internal_Idx])
					break;

				u16val = (uint16_t)((buf[1] << 8) | buf[0]);
				res = (*dl_ju16_func[internal_Idx])(internal_Idx , u16val);

				if(SUCCESS == res)
				{
					memcpy(&dl_ju16[internal_Idx], &buf[0] ,sizeof(uint16_t));
				}

				break;
			case DL_JU32:

				/* Validate the field */
				if (NULL == *dl_ju32_func[internal_Idx])
					break;

				u32val = (int32_t)((buf[3] << 24) | (buf[2] << 16) | (buf[1] << 8) | (buf[0]));
				res = (*dl_ju32_func[internal_Idx])(internal_Idx , u32val);

				if(SUCCESS == res)
				{
					memcpy(&dl_ju32[internal_Idx], &buf[0] ,sizeof(uint32_t));
				}

				break;

			res = SUCCESS;

			case NOT_SUPPRTED:
			/*Do nothing*/
			break;

	}
	return res;
}

/** @brief Get_data_type
 *
 *  @param  dl_index[IN]   : DB index value
 *
 *  @return  ret
 *
 */
uint8_t Get_data_type(uint16_t dl_index)
{
	uint8_t ret = 0;

	if((dl_index>START_U8BIT)&&(dl_index<END_U8BIT))
	{
		ret = DLU8;
	}
	else if((dl_index>START_U16BIT)&&(dl_index<END_U16BIT))
	{
		ret = DLU16;
	}
	else if((dl_index>START_U32BIT)&&(dl_index<END_U32BIT))
	{
		ret = DLU32;
	}
	else if((dl_index>START_U64BIT)&&(dl_index<END_U64BIT))
	{
		ret = DLU64;
	}
	else if((dl_index>START_S8BIT)&&(dl_index<END_S8BIT))
	{
		ret = DLS8;
	}
	else if((dl_index>START_S16BIT)&&(dl_index<END_S16BIT))
	{
		ret = DLS16;
	}
	else if((dl_index>START_S32BIT)&&(dl_index<END_S32BIT))
	{
		ret = DLS32;
	}
	else if((dl_index>START_FLOAT)&&(dl_index<END_FLOAT))
	{
		ret = DLFLOAT;
	}
	else if((dl_index>START_EEPROM)&&(dl_index<END_EEPROM))
	{
		ret = DL_EEPROM;
	}
	else if((dl_index>START_BUF512BIT)&&(dl_index<END_BUF512BIT))
	{
		ret = DL_BUF512BIT;
	}
	else if((dl_index>START_J1939U8BIT)&&(dl_index<END_J1939U8BIT))
	{
		ret = DL_JU8;
	}
	else if((dl_index>START_J1939U16BIT)&&(dl_index<END_J1939U16BIT))
	{
		ret = DL_JU16;
	}
	else if((dl_index>START_J1939U32BIT)&&(dl_index<END_J1939U32BIT))
	{
		ret = DL_JU32;
	}
	else
	{
		ret = NOT_SUPPRTED;
	}

	return ret;
}

/** @brief Get_Element_idx
 *
 *  @param  dl_index[IN]   : DB index value
 *
 *  @return  ret
 *
 */
static uint16_t Get_Element_idx(uint32_t dl_index)
{
	uint16_t ret = 0;

	if((dl_index>START_U8BIT)&&(dl_index<END_U8BIT))
	{
		ret = (dl_index - START_U8BIT)-1;
	}
	else if((dl_index>START_U16BIT)&&(dl_index<END_U16BIT))
	{
		ret = (dl_index - START_U16BIT)-1;
	}
	else if((dl_index>START_U32BIT)&&(dl_index<END_U32BIT))
	{
		ret = (dl_index - START_U32BIT)-1;
	}
	else if((dl_index>START_U64BIT)&&(dl_index<END_U64BIT))
	{
		ret = (dl_index - START_U64BIT)-1;
	}
	else if((dl_index>START_S8BIT)&&(dl_index<END_S8BIT))
	{
		ret = (dl_index - START_S8BIT)-1;
	}
	else if((dl_index>START_S16BIT)&&(dl_index<END_S16BIT))
	{
		ret = (dl_index - START_S16BIT)-1;
	}
	else if((dl_index>START_S32BIT)&&(dl_index<END_S32BIT))
	{
		ret = (dl_index - START_S32BIT)-1;
	}
	else if((dl_index>START_FLOAT)&&(dl_index<END_FLOAT))
	{
		ret = (dl_index - START_FLOAT)-1;
	}
	else if((dl_index>START_EEPROM)&&(dl_index<END_EEPROM))
	{
		ret = (dl_index - START_EEPROM)-1;
	}
	else if((dl_index>START_BUF512BIT)&&(dl_index<END_BUF512BIT))
	{
		ret = (dl_index - START_BUF512BIT)-1;
	}
	else if((dl_index>START_J1939U8BIT)&&(dl_index<END_J1939U8BIT))
	{
		ret = (dl_index - START_J1939U8BIT)-1;
	}
	else if((dl_index>START_J1939U16BIT)&&(dl_index<END_J1939U16BIT))
	{
		ret = (dl_index - START_J1939U16BIT)-1;
	}
	else if((dl_index>START_J1939U32BIT)&&(dl_index<END_J1939U32BIT))
	{
		ret = (dl_index - START_J1939U32BIT)-1;
	}
	else
	{
		ret = NOT_VALID_IDX;
	}
	return ret;
}

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
