/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : IO_Expander_TCA9535.h
   Author             : Zaid
   Version            : V0.0.0.1
   Origination Date   : 28/01/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the IO_Expander platform service declarations

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             28/01/2022           Zaid

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _IO_EXPANDER_TCA9535_SERVICE_H_
#define	_IO_EXPANDER_TCA9535_SERVICE_H_

/************************** I2C Address ***************************************/
#define TCA9535_ADDRESS			0x44 		// I2C Address adr [0100 00 + a2 a1 a0 ]+ R/W
#define TCA9535_2_ADDRESS       0x48 		// I2C Address adr [0100 00 + a2 a1 a0 ]+ R/W
											// ADDR tied to P2.2 of LaunchPad
/************************** I2C Registers *************************************/
#define TCA9535_INPUT_REG0 		0x00		// Input status register
#define TCA9535_INPUT_REG1 		0x01		// Input status register
#define TCA9535_OUTPUT_REG0		0x02		// Output register to change state of output BIT set to 1, output set HIGH
#define TCA9535_OUTPUT_REG1		0x03		// Output register to change state of output BIT set to 1, output set HIGH
#define TCA9535_POLARITY_REG0 	0x04		// Polarity inversion register. BIT '1' inverts input polarity of register 0x00
#define TCA9535_POLARITY_REG1 	0x05		// Polarity inversion register. BIT '1' inverts input polarity of register 0x00
#define TCA9535_CONFIG_REG0		0x06		// Configuration register. BIT = '1' sets port to input BIT = '0' sets port to output
#define TCA9535_CONFIG_REG1		0x07		// Configuration register. BIT = '1' sets port to input BIT = '0' sets port to output

#define TCA9539_ADDRESS_EVALUATION_BOARD  0x77

/*!
 * IO Expander Read Timeout
 */
#define IO_EXP_TIMEOUT 100

struct TCA9535_sBit{
	unsigned char B0:1;
	unsigned char B1:1;
	unsigned char B2:1;
	unsigned char B3:1;
	unsigned char B4:1;
	unsigned char B5:1;
	unsigned char B6:1;
	unsigned char B7:1;
};

union TCA9535_uInputPort{
	unsigned char all;
	struct TCA9535_sBit bit;
};

struct TCA9535_sInput{
	union TCA9535_uInputPort P0;
	union TCA9535_uInputPort P1;
};


union TCA9535_uInput{
	unsigned short all;
	struct TCA9535_sInput Port;
};

union TCA9535_uBitAll{
	unsigned char 		all;
	struct TCA9535_sBit	bit;
};

/*
union TCA9535_uOutputP1{
	unsigned char 		all;
	struct TCA9535_sBit	bit;
};*/

struct TCA9535_sOutput{
	union TCA9535_uBitAll	P0;
	union TCA9535_uBitAll	P1;
};

union TCA9535_uOutput{
	unsigned short	all;
	struct TCA9535_sOutput	Port;
};
/*
union TCA9535_uPolarityInversionP0{
	unsigned char all;
	struct TCA9535_sBit bit;
};

union  TCA9535_uPolarityInversionP1{
	unsigned char	all;
	struct TCA9535_sBit bit;
};
*/
struct TCA9535_sPolarityInversion{
	union TCA9535_uBitAll P0;
	union TCA9535_uBitAll P1;
};

union TCA9535_uPolarityInversion{
	unsigned short all;
	struct TCA9535_sPolarityInversion Port;
};
/*
union TCA9535_uConfigP0{
	unsigned char all;
	struct TCA9535_sBit bit;
};

union  TCA9535_uConfigP1{
	unsigned char	all;
	struct TCA9535_sBit bit;
};*/

struct TCA9535_sConfig{
	union TCA9535_uBitAll P0;
	union TCA9535_uBitAll P1;
};

union TCA9535_uConfig{
	unsigned short all;
	struct TCA9535_sConfig Port;
};

struct sTCA9535Regs{
	union TCA9535_uInput 				Input;
	union TCA9535_uOutput 				Output;
	union TCA9535_uPolarityInversion 	PolarityInversion;
	union TCA9535_uConfig				Config;
};

typedef struct {
	union TCA9535_uInput 				Input;
	union TCA9535_uOutput				Output;
	union TCA9535_uPolarityInversion	PolarityInversion;
	union TCA9535_uConfig				Config;
} TCA9535Regs;

struct TCA9539_sBit{
	unsigned char B0:1;
	unsigned char B1:1;
	unsigned char B2:1;
	unsigned char B3:1;
	unsigned char B4:1;
	unsigned char B5:1;
	unsigned char B6:1;
	unsigned char B7:1;
};

///////////////////////////////////////////////////input

union TCA9539_uInputPort{
	unsigned char all;
	struct TCA9539_sBit bit;
};

struct TCA9539_sInput{
	union TCA9539_uInputPort P0;
	union TCA9539_uInputPort P1;
};

union TCA9539_uInput{
	unsigned short all;
	struct TCA9539_sInput Port;
};

/////////////////////////////////////////////output
union TCA9539_uOutputP0{
	unsigned char 		all;
	struct TCA9539_sBit	bit;
};

union TCA9539_uOutputP1{
	unsigned char 		all;
	struct TCA9539_sBit	bit;
};

struct TCA9539_sOutput{
	union TCA9539_uOutputP0	P0;
	union TCA9539_uOutputP1	P1;
};

union TCA9539_uOutput{
	unsigned short	all;
	struct TCA9539_sOutput	Port;
};

/////////////////////////////////////////polarity inversion
union TCA9539_uPolarityInversionP0{
	unsigned char all;
	struct TCA9539_sBit bit;
};

union  TCA9539_uPolarityInversionP1{
	unsigned char	all;
	struct TCA9539_sBit bit;
};

struct TCA9539_sPolarityInversion{
	union TCA9539_uPolarityInversionP0 P0;
	union TCA9539_uPolarityInversionP1 P1;
};

union TCA9539_uPolarityInversion{
	unsigned short all;
	struct TCA9539_sPolarityInversion Port;
};

//////////////////////////////////////////////////////config
union TCA9539_uConfigP0{
	unsigned char all;
	struct TCA9539_sBit bit;
};

union  TCA9539_uConfigP1{
	unsigned char	all;
	struct TCA9539_sBit bit;
};

struct TCA9539_sConfig{
	union TCA9539_uConfigP0 P0;
	union TCA9539_uConfigP1 P1;
};


union TCA9539_uConfig{
	unsigned short all;
	struct TCA9539_sConfig Port;
};

typedef struct {
	union TCA9539_uInput 				Input;
	union TCA9539_uOutput				Output;
	union TCA9539_uPolarityInversion	PolarityInversion;
	union TCA9539_uConfig				Config;
} TCA9539Regs;


/*!
 * Function declaration
 */
int8_t Init_IOExpander(I2C_HandleTypeDef *hi2c);
int8_t TakeIOExpanderLock();
int8_t GiveIOExpanderLock();


extern void IO_Expander_init();
extern int8_t Set_OutputHigh();
extern int8_t Set_OutputLow();
extern int8_t Set_OutputOpen();

void TCA9535InitDefault(TCA9535Regs* Regs);

void ConfigOutput(uint8_t type);


HAL_StatusTypeDef TCA9539ReadInputReg(I2C_HandleTypeDef *hi2c,
		TCA9535Regs* Regs, uint16_t adr);
HAL_StatusTypeDef TCA9535WriteOutput(I2C_HandleTypeDef *hi2c,
		TCA9535Regs * Regs,uint16_t adr);
HAL_StatusTypeDef TCA9535ReadOutput(I2C_HandleTypeDef *hi2c,
		TCA9535Regs * Regs,uint16_t adr);
HAL_StatusTypeDef TCA9535WriteConfig(I2C_HandleTypeDef *hi2c,
		TCA9535Regs * Regs, uint16_t adr);
HAL_StatusTypeDef TCA9535ReadConfig(I2C_HandleTypeDef *hi2c,
		TCA9535Regs * Regs, uint16_t adr);
HAL_StatusTypeDef TCA9535WritePolarity(I2C_HandleTypeDef *hi2c,
		TCA9535Regs * Regs, uint16_t adr);
HAL_StatusTypeDef TCA9535ReadPolarity(I2C_HandleTypeDef *hi2c,
		TCA9535Regs * Regs, uint16_t adr);

#endif	//_IO_EXPANDER_TCA9535_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
