/****************************************************************************
Copyright (c) 2012 Maxima Technologies and Systems
All Rights Reserved
File Name : camera.h
Author : Name Last_Name
Version : V0.0.0.1
Origination Date : 10/15/2019
Description : C Header File.
Environment : Independant
Processor: : Independant
-----------------------------------------------------------------------------
Description:
Generic Camera structure and constants needed for the camera decoder.
-----------------------------------------------------------------------------
File Revision History:
-----------------------------------------------------------------------------
Version Date Programmer
0.0.0.0 04/04/2011 Name Last_Name
Notes: - Initial Version
-----------------------------------------------------------------------------
Version Date Programmer
0.0.0.1 31/03/2011 Name Last_Name
Notes: - Second Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef __CAMERA_H
#define __CAMERA_H

#ifdef __cplusplus
 extern "C" {
#endif 

/* Includes ---------------------------------------------------------------*/
#include <stdint.h>

/* Public typedef ---------------------------------------------------------*/
typedef struct
{
  void     (*Init)(uint16_t, uint32_t);
  uint16_t (*ReadID)(uint16_t);  
  void     (*Config)(uint16_t, uint32_t, uint32_t, uint32_t);
}CAMERA_DrvTypeDef;

/* Public define ----------------------------------------------------------*/
#define CAMERA_R160x120                 0x00   /* QQVGA Resolution                     */
#define CAMERA_R320x240                 0x01   /* QVGA Resolution                      */
#define CAMERA_R480x272                 0x02   /* 480x272 Resolution                   */
#define CAMERA_R640x480                 0x03   /* VGA Resolution                       */  

#define CAMERA_CONTRAST_BRIGHTNESS      0x00   /* Camera contrast brightness features  */
#define CAMERA_BLACK_WHITE              0x01   /* Camera black white feature           */
#define CAMERA_COLOR_EFFECT             0x03   /* Camera color effect feature          */

#define CAMERA_BRIGHTNESS_LEVEL0        0x00   /* Brightness level -2         */
#define CAMERA_BRIGHTNESS_LEVEL1        0x01   /* Brightness level -1         */
#define CAMERA_BRIGHTNESS_LEVEL2        0x02   /* Brightness level 0          */
#define CAMERA_BRIGHTNESS_LEVEL3        0x03   /* Brightness level +1         */
#define CAMERA_BRIGHTNESS_LEVEL4        0x04   /* Brightness level +2         */

#define CAMERA_CONTRAST_LEVEL0          0x05   /* Contrast level -2           */
#define CAMERA_CONTRAST_LEVEL1          0x06   /* Contrast level -1           */
#define CAMERA_CONTRAST_LEVEL2          0x07   /* Contrast level  0           */
#define CAMERA_CONTRAST_LEVEL3          0x08   /* Contrast level +1           */
#define CAMERA_CONTRAST_LEVEL4          0x09   /* Contrast level +2           */    
    
#define CAMERA_BLACK_WHITE_BW           0x00   /* Black and white effect      */
#define CAMERA_BLACK_WHITE_NEGATIVE     0x01   /* Negative effect             */
#define CAMERA_BLACK_WHITE_BW_NEGATIVE  0x02   /* BW and Negative effect      */
#define CAMERA_BLACK_WHITE_NORMAL       0x03   /* Normal effect               */
                                        
#define CAMERA_COLOR_EFFECT_NONE        0x00   /* No effects                  */
#define CAMERA_COLOR_EFFECT_BLUE        0x01   /* Blue effect                 */
#define CAMERA_COLOR_EFFECT_GREEN       0x02   /* Green effect                */
#define CAMERA_COLOR_EFFECT_RED         0x03   /* Red effect                  */
#define CAMERA_COLOR_EFFECT_ANTIQUE     0x04   /* Antique effect              */

#define PROC_FRAMES       10         // Frames to process before discard frames
#define DROP_FRAMES       1          // Frames to discard to alleviate controller load

/* Public macro -----------------------------------------------------------*/
/* Public variables -------------------------------------------------------*/
/* Public functions declaration -------------------------------------------*/

#ifdef __cplusplus
}
#endif

#endif /* __CAMERA_H */


/**************** (C) COPYRIGHT 2012 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/

/****************************************************************************
Copyright (c) 2012 Maxima Technologies and Systems
All Rights Reserved
File Name : stm32746g_discovery_camera.h
Author : upender chennoju
Version : V0.0.0.1
Origination Date : 10/15/2019
Description : C Header File.
Environment : Independant
Processor: : Independant
-----------------------------------------------------------------------------
Description:
General File Description
-----------------------------------------------------------------------------
File Revision History:
-----------------------------------------------------------------------------
Version Date Programmer
0.0.0.0 04/04/2011 Name Last_Name
Notes: - Initial Version
-----------------------------------------------------------------------------
Version Date Programmer
0.0.0.1 31/03/2011 Name Last_Name
Notes: - Second Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef __STM32746G_DISCOVERY_CAMERA_H
#define __STM32746G_DISCOVERY_CAMERA_H

#ifdef __cplusplus
 extern "C" {
#endif 

/* Includes ---------------------------------------------------------------*/
#include "adv7180.h"
//#include "stm32746g_discovery_i2c.h"
//#include "stm32h7xx_hal_dcmi.h"
#include "stm32h7xx_hal.h"

 typedef enum
 {
   BSP_IO_PIN_RESET = 0,
   BSP_IO_PIN_SET   = 1
 }BSP_IO_PinStateTypeDef;

/* Public typedef ---------------------------------------------------------*/
typedef enum 
{
  CAMERA_OK            = 0x00,
  CAMERA_ERROR         = 0x01,
  CAMERA_TIMEOUT       = 0x02,
  CAMERA_NOT_DETECTED  = 0x03,
  CAMERA_NOT_SUPPORTED = 0x04
}Camera_StatusTypeDef;

typedef enum
{
  NTSC_M_J             = 0x00,
  NTSC_443             = 0x01,
  PAL_M                = 0x02,
  PAL_60               = 0x03,
  PAL_B_G_H_I_D        = 0x04,
  SECAM                = 0x05,
  PAL_COMBINATION_N    = 0x06,
  SECAM_525            = 0X07,
}Detected_Standard;

/* Public define ----------------------------------------------------------*/
#define RESOLUTION_R160x120			CAMERA_R160x120      /* QQVGA Resolution     */
#define RESOLUTION_R320x240			CAMERA_R320x240      /* QVGA Resolution      */
#define RESOLUTION_R480x272			CAMERA_R480x272      /* 480x272 Resolution   */
#define RESOLUTION_R640x480			CAMERA_R640x480      /* VGA Resolution       */

#define CAMERA_VGA_RES_X			640
#define CAMERA_VGA_RES_Y			480
#define CAMERA_480x272_RES_X		480
#define CAMERA_480x272_RES_Y		272
#define CAMERA_QVGA_RES_X			320
#define CAMERA_QVGA_RES_Y			240
#define CAMERA_QQVGA_RES_X			160
#define CAMERA_QQVGA_RES_Y			120

#define BSP_CAMERA_IRQHandler		DCMI_IRQHandler
#define BSP_CAMERA_DMA_IRQHandler	DMA2_Stream1_IRQHandler

/*!
 * Resize values
 */
#define WIDTH_240  					240
#define WIDTH_120  					120
#define WIDTH_60    				60
#define WIDTH_30    				30
#define HEIGHT_136					136
#define HEIGHT_68					68
#define HEIGHT_34					34

/*!
 *  Camera Display size
 */
#define DISPLAY_NONE				0
#define ENABLE_FULL_SCREEN_DISPLAY	1
#define RESIZE_IMAGE_TO_FULLSCREEN	2
#define DISPLAY_CROPPED_IMAGE		3

#define CAMERA_I2C_WRITE_ADDRESS         ((uint16_t)0x40)
#define CAMERA_I2C_READ_ADDRESS          ((uint16_t)0x41)
#define CAMERA_PIXEL_SIZE           2
#define LCD_RES_X                   480
#define LCD_RES_Y                   272
#define LCD_PIXEL_SIZE              2
#define LCD_HORZ_FILP               1
#define LCD_VERT_FILP               0


#define PS_PAL_CAMERA_Y0_HEIGHT_LAST_MISSING_COLS 24 //4x7 (7 columns) this needed when VERT_FILP is ON
#define PS_NTSC_CAMERA_Y0_HEIGHT_LAST_MISSING_COLS 948 //4x237 (237 columns) this needed when VERT_FILP is ON


/* Public macro -----------------------------------------------------------*/

/* Public variables -------------------------------------------------------*/

/* Public functions declaration -------------------------------------------*/
uint8_t BSP_CAMERA_Init();
uint8_t BSP_CAMERA_DeInit(void);
void    BSP_CAMERA_ContinuousStart(uint8_t *buff);
void    BSP_CAMERA_SnapshotStart(uint8_t *buff);
void    BSP_CAMERA_Suspend(void);
void    BSP_CAMERA_Resume(void);
uint8_t BSP_CAMERA_Stop(void);
void    BSP_CAMERA_PwrUp(void);
void    BSP_CAMERA_PwrDown(void);
void    BSP_CAMERA_LineEventCallback(void);
void    BSP_CAMERA_VsyncEventCallback(void);
void    BSP_CAMERA_FrameEventCallback(void);
void    BSP_CAMERA_ErrorCallback(void);

/* Camera features functions prototype */
void    BSP_CAMERA_ContrastBrightnessConfig(uint32_t contrast_level, uint32_t brightness_level);
void    BSP_CAMERA_BlackWhiteConfig(uint32_t Mode);
void    BSP_CAMERA_ColorEffectConfig(uint32_t Effect);
   
/* These functions can be modified in case the current settings (e.g. DMA stream)
   need to be changed for specific application needs */
void BSP_CAMERA_MspInit(DCMI_HandleTypeDef *hdcmi, void *Params);
void BSP_CAMERA_MspDeInit(DCMI_HandleTypeDef *hdcmi, void *Params);
//void loadCameraToLCD(void);
#if 0
void loadCameraToLCDAsIts(uint16_t LCD_X0, uint16_t LCD_X_W0,
		             uint16_t LCD_Y0, uint16_t LCD_Y_H0,
					 uint16_t Cam_Cap_line, uint16_t Cam_Cap_Pixel);
#endif
void loadCameraToLCDAsIts(uint16_t LCD_X0, uint16_t LCD_Y0,
					 uint16_t Cam_Cap_line, uint16_t Cam_Cap_Pixel);

void loadCameraToLCD(uint16_t LCD_X0, uint16_t LCD_X_W0,
		             uint16_t LCD_Y0, uint16_t LCD_Y_H0,
					 uint16_t Cam_Cap_line, uint16_t Cam_Cap_Pixel);
#if 0
void loadCameraToLCDReSize_FullScreen(uint16_t LCD_X_W0,
		                              uint16_t LCD_Y_H0,
					                  uint16_t Cam_Cap_line,
									  uint16_t Cam_Cap_Pixel);
#endif
void loadCameraToLCDReSize_FullScreen(uint16_t LCD_X_W0,
		                              uint16_t LCD_Y_H0);
void start_camera(void);
void Camera_LCD_Config(void);
void CAMERA_PowerON();
void FullScreenDisplay();
void resize600to480(uint8_t *rgbdata, uint8_t *fb);
void loadCameraToLCDFullScreen(uint16_t LCD_X0, uint16_t LCD_Y0,
		 uint16_t Cam_Cap_line, uint16_t Cam_Cap_Pixel);
void CropCameraImageResizetoLCDSize(uint16_t x0_origin, uint16_t y0_origin,
							  uint16_t x0_width, uint16_t y0_height,
							  uint16_t lcd_x0_origin, uint16_t lcd_y0_origin);
void resizeframetofullscreen(uint16_t  *src,
							  uint16_t  x0w,
							  uint16_t  y0h);
void loadCameraToLCDReSize_FullScreen(uint16_t LCD_X_W0,
		                              uint16_t LCD_Y_H0);
void loadCameraToLCDAsIts(uint16_t LCD_X0, uint16_t LCD_Y0,
					 uint16_t Cam_Cap_line, uint16_t Cam_Cap_Pixel);
Detected_Standard GetVideoStandard(void);
void VideoStandardID(void);
uint8_t bVidDet_PAL;
uint8_t bVidDet_NTSC;
uint8_t bVidDet_SECAM;
uint16_t uiLCDOffset_X;
uint16_t uiLCDOffset_Y;
uint8_t bLCD_Hor_Flip;
uint8_t bLCD_Ver_Flip;
HAL_StatusTypeDef ReStart(void);

void BSP_LCD_LayerDefaultInit(uint16_t LayerIndex, uint32_t FB_Address, uint8_t format,
		   	   	   	   	   	  uint16_t X0,
							  uint16_t Y0,
							  uint16_t W0,
							  uint16_t H0);

#ifdef __cplusplus
}
#endif

#endif /* __STM32746G_DISCOVERY_CAMERA_H */

/**************** (C) COPYRIGHT 2012 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
