/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : input_control.h
   Author             : Zaid
   Version            : V0.0.0.1
   Origination Date   : 28/01/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the Driver code configuration structures and macros

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             28/01/2022           Zaid

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

#ifndef __INPUT_H
#define __INPUT_H

#include "stdint.h"
#define INPUT_MAX_INPUTS		6//5 analog inputs + 1 current + 1 battery monitor

#define INPUT_R_BETWEEN_INPUTS	390		//this is most likely wrong since inm has an extra 1M resistor on it which ref doesn't have.
#define INPUT_MAX_RESISTANCE	10000
#define INPUT_GAIN				1.516f
#define INPUT_CURRENT_DIV		4095*56

#define INPUT_CLOCK_PIN			GPIO_PIN_4
#define INPUT_CLOCK_PORTH		GPIOH

#define INPUT_DATA_PIN			GPIO_PIN_2		//called iconf on the schematic for some reason
#define INPUT_DATA_PORTH		GPIOH

#define INPUT_BLANK_PIN			GPIO_PIN_3		//called I_RES
#define INPUT_BLANK_PORTE		GPIOE

/*!
\enum
\brief
*/
typedef enum{
	INPUT_FREQUENCY=1,		// 1 none
	INPUT_CURRENT,			// 2 ref with pd1 1
	INPUT_VOLTAGE_LOW,		// 3 inm1 with en1 1
	INPUT_RESISTANCE,		// 4 inm1/ref1 calc   AI_CalculateResistance(ref1, (in1 * 1.516f), 124);
	DIGITAL_STG,			// 5 input active low
	DIGITAL_STB,			// 6 input active high
	INPUT_VOLTAGE_HIGH,		// 7 plain inm1
    INPUT_VOLTAGE_LOW_6V,   // 8
	BATT_MONITOR,			// 9 batt monitor
	EXP_IO_POWER_DOWN,
}INPUT_TYPE;


extern
void ConfigureAI();
//----------------------------------------------------------------------------------------------------------------
void INPUTS_init();

//----------------------------------------------------------------------------------------------------------------
void INPUTS_deinit();

//----------------------------------------------------------------------------------------------------------------
//take the raw data and convert it to whatever type it needs to be
//also takes care of averaging
void AI_Update();

//----------------------------------------------------------------------------------------------------------------
void INPUTS_SetType(int index, INPUT_TYPE _input_type);

//----------------------------------------------------------------------------------------------------------------
INPUT_TYPE INPUTS_GetType(int index);

//----------------------------------------------------------------------------------------------------------------
void INPUT_Powerdown();
extern

void write_shift_register(uint8_t current_disable);

#endif

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
