/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : IO_Expander_TCA9535.c
   Author             : Zaid
   Version            : V0.0.0.1
   Origination Date   : 28/01/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the IP_Expander_TCA9535 HAL driver functions

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             28/01/2022           Zaid

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../../../Core/Maximatecc/Inc/Common.h"
#include "../inc/input_control.h"
#include "../inc/IO_Expander_TCA9535.h"

/* USER CODE END Includes */

/* USER CODE BEGIN Global Variable */

/* USER CODE END Global Variable */

/** @brief Initialize the IO Expander
 *
 *  This function intialize the IO Expander software Resource
 *
 *  @param  None
 *
 *
 *  @return 0 : SUCCESS
 *          1 : FAILURE
 */
int8_t Init_IOExpander(I2C_HandleTypeDef *hi2c)
{
	TCA9535Regs Regs;
	TCA9535Regs rRegs;

	/* Initialize all the GPIO Pins */
    memset(&Regs, 0x00, sizeof(Regs));
    memset(&rRegs, 0x00, sizeof(Regs));
    TCA9535WriteConfig(hi2c, &Regs, TCA9535_ADDRESS);
 	HAL_Delay(20);

    TCA9535ReadConfig(hi2c, &rRegs, TCA9535_ADDRESS);
 	HAL_Delay(10);

    TCA9535WriteConfig(hi2c, &Regs, TCA9535_2_ADDRESS);
 	HAL_Delay(10);

 	memset(&rRegs, 0x00, sizeof(Regs));
    TCA9535ReadConfig(hi2c, &rRegs, TCA9535_2_ADDRESS);
 	HAL_Delay(10);

 	TCA9535WritePolarity(hi2c, &Regs, TCA9535_ADDRESS);
 	HAL_Delay(10);

 	memset(&rRegs, 0x00, sizeof(Regs));
    TCA9535ReadPolarity(hi2c, &rRegs, TCA9535_ADDRESS);
 	HAL_Delay(10);

 	TCA9535WritePolarity(hi2c, &Regs, TCA9535_2_ADDRESS);
    memset(&rRegs, 0x00, sizeof(Regs));
 	HAL_Delay(10);

 	TCA9535ReadPolarity(hi2c, &rRegs, TCA9535_2_ADDRESS);
 	HAL_Delay(10);
    TCA9535WriteOutput(hi2c, &Regs, TCA9535_ADDRESS);

    memset(&rRegs, 0x00, sizeof(Regs));
    HAL_Delay(10);
    TCA9535ReadOutput(hi2c, &rRegs, TCA9535_ADDRESS);
 	HAL_Delay(10);
    TCA9535WriteOutput(hi2c, &Regs, TCA9535_2_ADDRESS);

    memset(&rRegs, 0x00, sizeof(Regs));
 	HAL_Delay(10);
    TCA9535ReadOutput(hi2c, &rRegs, TCA9535_2_ADDRESS);
 	HAL_Delay(10);

 	return SUCCESS;
}


/** @brief Get the Mutex Lock
 *
 *  This function gets the IO expander Mutex Lock
 *
 *  @param  None
 *
 *  @return 0 : SUCCESS
 *          1 : FAILURE
 */
int8_t TakeIOExpanderLock()
{

	int8_t ret = SUCCESS;

	return ret;
}


/** @brief Release the Mutex Lock
 *
 *  This function releases the IO expander Mutex Lock
 *
 *  @param  None
 *
 *  @return 0 : SUCCESS
 *          1 : FAILURE
 */
int8_t GiveIOExpanderLock()
{
	int8_t ret = SUCCESS;

	return ret;
}

/**
CIN_VR_EN       CIN_PDA         CINPDB          V32/DIAH
0               0               0               Resistance/DI_AL
1               0               0               Voltage 3.3v/Frequency
1               0               1               Voltage 32V/ DI_AH
1               1               0               Voltage 6V
*/
void TCA9535Init1Default(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;
	Regs->PolarityInversion.all = 0x0000;

	/*	Resistance */
	Regs->Output.all = 0;
}

void TCA9535Init2Default(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;

	/*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;
	Regs->PolarityInversion.all = 0x0000;

	/*	Resistance */
	Regs->Output.all = 0;
}

void TCA9535Init1_32Voltage_DigitalInputActiveHigh(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	Regs->PolarityInversion.all = 0x0000;

	/*	AN1 32V */
	Regs->Output.Port.P0.bit.B0 = 1;
	Regs->Output.Port.P0.bit.B1 = 0;
	Regs->Output.Port.P0.bit.B2 = 1;

	/*	AN6 3.3V , for this input doesn't support 32V */
	/*	AN6 CURRENT */
	Regs->Output.Port.P0.bit.B3 = 1;
	Regs->Output.Port.P0.bit.B4 = 0;
	Regs->Output.Port.P0.bit.B5 = 1;

	/*	AN5 32V */
	Regs->Output.Port.P1.bit.B0 = 1;
	Regs->Output.Port.P1.bit.B1 = 0;
	Regs->Output.Port.P1.bit.B2 = 1;

	/*	AN4 32V */
	Regs->Output.Port.P1.bit.B3 = 1;
	Regs->Output.Port.P1.bit.B4 = 0;
	Regs->Output.Port.P1.bit.B5 = 1;

}


void TCA9535Init2_32Voltage_DigitalInputActiveHigh(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;

	/*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;
	Regs->PolarityInversion.all = 0x0000;

	/* AN2 32V */
	Regs->Output.Port.P0.bit.B5 = 1;/*	EN2 */
	Regs->Output.Port.P0.bit.B6 = 1;/*	B2 */
	Regs->Output.Port.P0.bit.B7 = 0;/*	A2 */

	/*	AN3 32V */
	Regs->Output.Port.P1.bit.B0 = 1;/*	EN3 */
	Regs->Output.Port.P1.bit.B1 = 1;/*	B3 */
	Regs->Output.Port.P1.bit.B2 = 0;/*	A3 */

}


void TCA9535Init1_6Voltage(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	Regs->PolarityInversion.all = 0x0000;

	/*	AN1 6V */
	Regs->Output.Port.P0.bit.B0 = 1;
	Regs->Output.Port.P0.bit.B1 = 1;
	Regs->Output.Port.P0.bit.B2 = 0;

	/*	AN6 6V */
	Regs->Output.Port.P0.bit.B3 = 0;/*	PDB6 */
	Regs->Output.Port.P0.bit.B4 = 1;/*	PDA6 */
	Regs->Output.Port.P0.bit.B5 = 1;/*	EN6 */

	/*	AN5 6V */
	Regs->Output.Port.P1.bit.B0 = 1;
	Regs->Output.Port.P1.bit.B1 = 1;
	Regs->Output.Port.P1.bit.B2 = 0;

	/*	AN4 6V */
	Regs->Output.Port.P1.bit.B3 = 0;/*	pdB4 */
	Regs->Output.Port.P1.bit.B4 = 1;/*	pdA4 */
	Regs->Output.Port.P1.bit.B5 = 1;/*	en4 */

}


void TCA9535Init2_6Voltage(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;
	 /*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;
	Regs->PolarityInversion.all = 0x0000;

    /*	AN2 6V */
	Regs->Output.Port.P0.bit.B5 = 1;/*	EN2 */
	Regs->Output.Port.P0.bit.B6 = 0;/*	B2 */
	Regs->Output.Port.P0.bit.B7 = 1;/*	A2 */

	/*	AN3 6V */
	Regs->Output.Port.P1.bit.B0 = 1;/*	EN3 */
	Regs->Output.Port.P1.bit.B1 = 0;/*	B3 */
	Regs->Output.Port.P1.bit.B2 = 1;/*	A3 */

}

void TCA9535Init1_3V_Frequency(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	Regs->PolarityInversion.all = 0x0000;

	/*	AN1 3.3V | Frequency */
	Regs->Output.Port.P0.bit.B0 = 1;/*	EN1 */
	Regs->Output.Port.P0.bit.B1 = 0;/*	PDA1 */
	Regs->Output.Port.P0.bit.B2 = 0;/*	PDB1 */

	/*	AN6 3.3V | Frequency */
	Regs->Output.Port.P0.bit.B3 = 0;/*	PDB6 */
	Regs->Output.Port.P0.bit.B4 = 0;/*	PDA6 */
	Regs->Output.Port.P0.bit.B5 = 1;/*	EN6 */

	/*	AN5 3.3V | Frequency */
	Regs->Output.Port.P1.bit.B0 = 1;/*	EN5 */
	Regs->Output.Port.P1.bit.B1 = 0;/*	PDA5 */
	Regs->Output.Port.P1.bit.B2 = 0;/*	PDB5 */

	/*	AN4 3.3V | Frequency */
	Regs->Output.Port.P1.bit.B3 = 0;/*	PDB4 */
	Regs->Output.Port.P1.bit.B4 = 0;/*	PDA4 */
	Regs->Output.Port.P1.bit.B5 = 1;/*	EN4 */

}


void TCA9535Init2_3V_Frequency(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;

	/*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;
	Regs->PolarityInversion.all = 0x0000;

	/*	AN2 3.3V | Frequency */
	Regs->Output.Port.P0.bit.B5 = 1;/*	EN2 */
	Regs->Output.Port.P0.bit.B6 = 0;/*	PDB2 */
	Regs->Output.Port.P0.bit.B7 = 0;/*	PDA2 */

	/*	AN3 3.3V | Frequency */
	Regs->Output.Port.P1.bit.B0 = 1;/*	EN3 */
	Regs->Output.Port.P1.bit.B1 = 0;/*	PDB3 */
	Regs->Output.Port.P1.bit.B2 = 0;/*	PDA3 */

}

void TCA9535Init2_OutputOpen(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;

	/*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;

	Regs->PolarityInversion.all = 0x0000;

	/* OUTPUT
	 * OPEN
	 * L = 0, H = 0
	 **/
	Regs->Output.Port.P0.bit.B0 = 0;/*	CDO_H1 */
	Regs->Output.Port.P0.bit.B2 = 0;/*	CDO_L1 */
}


void TCA9535Init2_OutputHigh(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;

	/*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;

	Regs->PolarityInversion.all = 0x0000;

	/* OUTPUT
	 * High
	 * L = 0, H = 1
	 **/
	Regs->Output.Port.P0.bit.B0 = 1;/*	CDO_H1 */
	Regs->Output.Port.P0.bit.B2 = 0;/*	CDO_L1 */

}


void TCA9535Init2_OutputLow(TCA9535Regs* Regs)
{
	/*	OUTPUTS */
	Regs->Config.all = 0x000;

	/*	INPUT st_H1 */
	Regs->Config.Port.P0.bit.B1 = 1;

	/*	AMBSENS_INT */
	Regs->Config.Port.P1.bit.B5 = 1;

	Regs->PolarityInversion.all = 0x0000;

	/* OUTPUT
	 * LOW
	 * L = 1, H = 0
	 **/
	Regs->Output.Port.P0.bit.B0 = 0;/*	CDO_H1 */
	Regs->Output.Port.P0.bit.B2 = 1;/*	CDO_L1 */

}


void TCA9535Init2_Leds(TCA9535Regs* Regs, uint8_t write_2_red,uint8_t write_2_amb)
{
	/*Outputs*/
	Regs->Config.Port.P1.bit.B3 = 0;/*	RED */
	Regs->Config.Port.P1.bit.B4 = 0;/*	AMBER */

	Regs->PolarityInversion.Port.P1.bit.B3 = 0;
	Regs->PolarityInversion.Port.P1.bit.B4 = 0;

	Regs->Output.Port.P1.bit.B3 = write_2_red;/*	LED_RED */
	Regs->Output.Port.P1.bit.B4 = write_2_amb;/*	LED_AMB */

}


HAL_StatusTypeDef TCA9539ReadInputReg(I2C_HandleTypeDef *hi2c,TCA9535Regs* Regs, uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Read_IT(hi2c, (uint16_t)adr, (uint16_t) TCA9535_INPUT_REG0, 1, (unsigned char*)&Regs->Input.all,2);

    return status;
}


HAL_StatusTypeDef TCA9535WriteOutput(I2C_HandleTypeDef *hi2c, TCA9535Regs * Regs,uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Write_IT(hi2c,  (uint16_t)adr, (uint16_t) TCA9535_OUTPUT_REG0, 1, (unsigned char*)&Regs->Output.all, 2);

	return status;
}

HAL_StatusTypeDef TCA9535ReadOutput(I2C_HandleTypeDef *hi2c, TCA9535Regs * Regs,uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Read_IT(hi2c,  (uint16_t)adr, (uint16_t) TCA9535_OUTPUT_REG0, 1, (unsigned char*)&Regs->Output.all, 2);

	return status;
}

HAL_StatusTypeDef TCA9535WriteConfig(I2C_HandleTypeDef *hi2c, TCA9535Regs * Regs, uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Write_IT(hi2c,  (uint16_t)adr, (uint16_t) TCA9535_CONFIG_REG0, 1, (unsigned char*)&Regs->Config.all, 2);

	return status;
}

HAL_StatusTypeDef TCA9535ReadConfig(I2C_HandleTypeDef *hi2c, TCA9535Regs * Regs, uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Read_IT(hi2c,  (uint16_t)adr, (uint16_t) TCA9535_CONFIG_REG0, 1, (unsigned char*)&Regs->Config.all, 2);

	return status;
}

HAL_StatusTypeDef TCA9535WritePolarity(I2C_HandleTypeDef *hi2c, TCA9535Regs * Regs, uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Write_IT(hi2c,  (uint16_t)adr, (uint16_t) TCA9535_POLARITY_REG0, 1,
			(unsigned char*)&Regs->PolarityInversion.all, 2);

    return status;
}


HAL_StatusTypeDef TCA9535ReadPolarity(I2C_HandleTypeDef *hi2c, TCA9535Regs * Regs, uint16_t adr)
{
	HAL_StatusTypeDef status;

	status = HAL_I2C_Mem_Read_IT(hi2c,  (uint16_t)adr, (uint16_t) TCA9535_POLARITY_REG0, 1,
			(unsigned char*)&Regs->PolarityInversion.all, 2);

    return status;
}

void TCA9535Init1_AI1(TCA9535Regs* Regs,uint8_t type)
{
	//  Regs->Config.all = 0x000;
	//OUTPUTS
	Regs->Config.Port.P0.bit.B0 =0;
	Regs->Config.Port.P0.bit.B1 =0;
	Regs->Config.Port.P0.bit.B2 =0;

	Regs->PolarityInversion.Port.P0.bit.B0 = 0;
	Regs->PolarityInversion.Port.P0.bit.B1 = 0;
	Regs->PolarityInversion.Port.P0.bit.B2 = 0;

	uint8_t en1;
	uint8_t pda1;
	uint8_t pdb1;
	en1 = 0; pda1 = 0; pdb1=0;

	switch(type)
	{
		case INPUT_FREQUENCY:
			en1 = 1; pda1 = 0; pdb1=0;
			break;

		case DIGITAL_STB:
		case INPUT_VOLTAGE_HIGH:
			en1 = 1; pda1 = 0; pdb1=1;
			break;

		case DIGITAL_STG:
		case INPUT_RESISTANCE:
			en1 = 0; pda1 = 0; pdb1=0;
			break;

		case INPUT_VOLTAGE_LOW_6V:
			en1 = 1; pda1 = 1; pdb1=0;
			break;

		default:
			break;

	}

	//AN1 3.3V | Frequency
	Regs->Output.Port.P0.bit.B0 = en1;//EN1
	Regs->Output.Port.P0.bit.B1 = pda1;//PDA1
	Regs->Output.Port.P0.bit.B2 = pdb1;//PDB1
}


void TCA9535Init2_AI2(TCA9535Regs* Regs,uint8_t type)
{
	uint8_t en2;
	uint8_t pda2;
	uint8_t pdb2;
	Regs->Config.Port.P0.bit.B5 =0;
	Regs->Config.Port.P0.bit.B6 =0;
	Regs->Config.Port.P0.bit.B7 =0;

	Regs->PolarityInversion.Port.P0.bit.B5 = 0;
	Regs->PolarityInversion.Port.P0.bit.B6 = 0;
	Regs->PolarityInversion.Port.P0.bit.B7 = 0;

	en2 = 1; pda2 = 0; pdb2=1;

	switch(type)
	{
		case INPUT_FREQUENCY:
			en2 = 1; pda2 = 0; pdb2=0;
			break;

		case DIGITAL_STB:
		case INPUT_VOLTAGE_HIGH:
			en2 = 1; pda2 = 0; pdb2=1;
			break;

		case DIGITAL_STG:
		case INPUT_RESISTANCE:
			en2 = 0; pda2 = 0; pdb2=0;
			break;

			en2 = 1; pda2 = 1; pdb2=0;
			break;

		default:
			break;
	}

	//AN2 3.3V | Frequency
	Regs->Output.Port.P0.bit.B5 = en2;//EN2
	Regs->Output.Port.P0.bit.B6 = pdb2;//PDB2
	Regs->Output.Port.P0.bit.B7 = pda2;//PDA2

}


void TCA9535Init2_AI3(TCA9535Regs* Regs,uint8_t type)
{
	uint8_t en3;
	uint8_t pda3;
	uint8_t pdb3;
	Regs->Config.Port.P1.bit.B0 =0;
	Regs->Config.Port.P1.bit.B1 =0;
	Regs->Config.Port.P1.bit.B2 =0;

	Regs->PolarityInversion.Port.P1.bit.B0 = 0;
	Regs->PolarityInversion.Port.P1.bit.B1 = 0;
	Regs->PolarityInversion.Port.P1.bit.B2 = 0;

	en3 = 1; pda3 = 1; pdb3=0;
	switch(type)
	{
		case INPUT_FREQUENCY:
			en3 = 1; pda3 = 0; pdb3=0;
			break;

		case DIGITAL_STB:
		case INPUT_VOLTAGE_HIGH:
			en3 = 1; pda3 = 0; pdb3=1;
			break;

		case DIGITAL_STG:
		case INPUT_RESISTANCE:
			en3 = 0; pda3 = 0; pdb3=0;
			break;

		case INPUT_VOLTAGE_LOW_6V:
			en3 = 1; pda3 = 1; pdb3=0;
			break;

		default:
			break;
	}

	//AN3 3.3V | Frequency
	Regs->Output.Port.P1.bit.B0 = en3;//EN3
	Regs->Output.Port.P1.bit.B1 = pdb3;//PDB3
	Regs->Output.Port.P1.bit.B2 = pda3;//PDA3

}

void TCA9535Init1_AI4(TCA9535Regs* Regs,uint8_t type)
{
	uint8_t en4;
	uint8_t pda4;
	uint8_t pdb4;


	Regs->Config.Port.P1.bit.B3 =0;
	Regs->Config.Port.P1.bit.B4 =0;
	Regs->Config.Port.P1.bit.B5 =0;

	Regs->PolarityInversion.Port.P1.bit.B3 = 0;
	Regs->PolarityInversion.Port.P1.bit.B4 = 0;
	Regs->PolarityInversion.Port.P1.bit.B5 = 0;

	en4 = 1; pda4 = 0; pdb4=0;
	switch(type)
	{
		case INPUT_FREQUENCY:
			en4 = 1; pda4 = 0; pdb4=0;
			break;

		case DIGITAL_STB:
		case INPUT_VOLTAGE_HIGH:
			en4 = 1; pda4 = 0; pdb4=1;
			break;

		case DIGITAL_STG:
		case INPUT_RESISTANCE:
			en4 = 0; pda4 = 0; pdb4=0;
			break;

		case INPUT_VOLTAGE_LOW_6V:
			en4 = 1; pda4 = 1; pdb4=0;
			break;

		default:
			break;
	}

	Regs->Output.Port.P1.bit.B3 = pdb4;//PDB4
	Regs->Output.Port.P1.bit.B4 = pda4;//PDA4
	Regs->Output.Port.P1.bit.B5 = en4;//EN4
}

void TCA9535Init1_AI5(TCA9535Regs* Regs,uint8_t type)
{
	uint8_t en5;
	uint8_t pda5;
	uint8_t pdb5;
	Regs->Config.Port.P1.bit.B0 =0;
	Regs->Config.Port.P1.bit.B1 =0;
	Regs->Config.Port.P1.bit.B2 =0;

	Regs->PolarityInversion.Port.P1.bit.B0 = 0;
	Regs->PolarityInversion.Port.P1.bit.B1 = 0;
	Regs->PolarityInversion.Port.P1.bit.B2 = 0;
	en5 = 0; pda5 = 1; pdb5=1;

	switch(type)
	{
		case INPUT_FREQUENCY:
			en5 = 1; pda5 = 0; pdb5=0;
			break;

		case DIGITAL_STB:
		case INPUT_VOLTAGE_HIGH:
			en5 = 1; pda5 = 0; pdb5=1;
			break;

		case DIGITAL_STG:
		case INPUT_RESISTANCE:
			en5 = 0; pda5 = 0; pdb5=0;
			break;

		case INPUT_VOLTAGE_LOW_6V:
			en5 = 1; pda5 = 1; pdb5=0;
			break;

		default:
			break;
	}

	Regs->Output.Port.P1.bit.B0 = en5;//EN5
	Regs->Output.Port.P1.bit.B1 = pda5;//PDA5
	Regs->Output.Port.P1.bit.B2 = pdb5;//PDB5
}


void TCA9535Init1_AI6(TCA9535Regs* Regs,uint8_t type)
{
	uint8_t en6;
	uint8_t pda6;
	uint8_t pdb6;

	Regs->Config.Port.P0.bit.B3 =0;
	Regs->Config.Port.P0.bit.B4 =0;
	Regs->Config.Port.P0.bit.B5 =0;

	Regs->PolarityInversion.Port.P1.bit.B3 = 0;
	Regs->PolarityInversion.Port.P1.bit.B4 = 0;
	Regs->PolarityInversion.Port.P1.bit.B5 = 0;

	en6 = 1; pda6= 0; pdb6=1;
	/*This input shall be always set to INPUT_CURRENT configuration*/
	switch(type)
	{
		case INPUT_CURRENT:
		case INPUT_FREQUENCY:
		case INPUT_VOLTAGE_LOW:
		case DIGITAL_STB:
		case INPUT_VOLTAGE_HIGH:
		case DIGITAL_STG:
		case INPUT_RESISTANCE:
		case INPUT_VOLTAGE_LOW_6V:
			en6 = 1; pda6= 0; pdb6=1;
		default:
			break;
	}

	Regs->Output.Port.P0.bit.B3 = pdb6;//PDB6
	Regs->Output.Port.P0.bit.B4 = pda6;//PDA6
	Regs->Output.Port.P0.bit.B5 = en6;//EN6
}


/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
