/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : Input_Frequency.c
   Author             : Zaid
   Version            : V0.0.0.1
   Origination Date   : 28/01/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the Frequency HAL driver functions

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             28/01/2022           Zaid
   0.0.0.2             10/04/2022           FOC Updated formula calcs,Zero Hz detection

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../../../Core/Maximatecc/Inc/Common.h"
#include "../../../../Core/Maximatecc/user_modify_files/User_Define.h"
/* USER CODE END Includes */

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
extern pvt_variable pv;

/* Frequency input - Configurable input 1 variables */
static uint32_t TIM3_fq_ovf = 0;
uint16_t TIM3_CH2_fq_capture_flag = 0;
uint32_t TIM3_CH2_IC1_Value1 = 0;
uint32_t TIM3_CH2_IC1_Value2 = 0;
uint32_t TIM3_CH2_DiffCapture = 0;
uint32_t TIM3_CH2_IC1_freq = 0;

/* Frequency input - Configurable input 2 variables */
static uint32_t TIM3_fq_ovf2 = 0;
uint16_t TIM3_CH3_fq_capture_flag = 0;
uint32_t TIM3_CH3_IC2_Value1 = 0;
uint32_t TIM3_CH3_IC2_Value2 = 0;
uint32_t TIM3_CH3_DiffCapture = 0;
uint32_t TIM3_CH3_IC2_freq = 0;

/* Frequency input - Configurable input 1 variables */
static uint32_t TIM2_fq_ovf = 0;
uint16_t TIM2_CH1_fq_capture_flag = 0;
uint32_t TIM2_CH1_IC1_Value1 = 0;
uint32_t TIM2_CH1_IC1_Value2 = 0;
uint32_t TIM2_CH1_DiffCapture = 0;
uint32_t TIM2_CH1_IC1_freq = 0;

/* Frequency input - Configurable input 2 variables */
static uint32_t TIM2_fq_ovf2 = 0;
uint16_t TIM2_CH2_fq_capture_flag = 0;
uint32_t TIM2_CH2_IC2_Value1 = 0;
uint32_t TIM2_CH2_IC2_Value2 = 0;
uint32_t TIM2_CH2_DiffCapture = 0;
uint32_t TIM2_CH2_IC2_freq = 0;

/* Frequency input - Configurable input 1 variables */
static uint32_t TIM13_fq_ovf = 0;
uint16_t TIM13_CH1_fq_capture_flag = 0;
uint32_t TIM13_CH1_IC1_Value1 = 0;
uint32_t TIM13_CH1_IC1_Value2 = 0;
uint32_t TIM13_CH1_DiffCapture = 0;
uint32_t TIM13_CH1_IC1_freq = 0;

/* Frequency input - Configurable input 1 variables */
static uint32_t TIM14_fq_ovf = 0;
uint16_t TIM14_CH1_fq_capture_flag = 0;
uint32_t TIM14_CH1_IC1_Value1 = 0;
uint32_t TIM14_CH1_IC1_Value2 = 0;
uint32_t TIM14_CH1_DiffCapture = 0;
uint32_t TIM14_CH1_IC1_freq = 0;

static uint32_t	CIN1_Hz;
static uint32_t CIN2_Hz;
static uint32_t CIN3_Hz;
static uint32_t CIN4_Hz;
static uint32_t CIN5_Hz;
static uint32_t CIN6_Hz;
static uint32_t DIN2_PWM_Hz;
static uint32_t FI_DIN2_PWM_DutyCycle;
static uint8_t TIM13_CH1_IC1_Active; //CIN1 Counting Hz
static uint8_t TIM14_CH1_IC1_Active; //CIN2 Counting Hz
static uint8_t TIM2_CH2_IC2_Active; //CIN3 Counting Hz
static uint8_t TIM2_CH1_IC1_Active; //CIN4 Counting Hz
static uint8_t TIM3_CH2_IC1_Active; //CIN5 Counting Hz
static uint8_t TIM3_CH2_IC2_Active; //CIN6 Counting Hz
static uint8_t vhConfigCluster;

uint32_t uwPrescalerValue = 0;

#if 1
uint16_t capturetim[10000];
uint16_t gindex = 0;
#endif

/*******************************************************************************
 * Function Name  : Freq_Set_CIN_VFQ_Freq
 * Description    : This function save current frequency input from CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/

void FI_Set_CIN1_Frequency(uint32_t value)
{
	CIN1_Hz = value;
}
/*******************************************************************************
 * Function Name  : FI_Get_CIN1_Frequency
 * Description    : This function return actual hertz value from CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CIN1_Frequency(void)
{
	return CIN1_Hz;
}
/*******************************************************************************
 * Function Name  : FI_Mon_CIN1_Frequency
 * Description    : This function reset flag to check frequency input feed CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Mon_CIN1_Frequency(void)
{
	TIM13_CH1_IC1_Active = 0;
}
/*******************************************************************************
 * Function Name  : FI_Chk_CIN1_Frequency
 * Description    : This function check flag frequency input feed CIN1
 * Input          : None
 * Output         : Input feeding running
 * Return         : None
 *******************************************************************************/
uint8_t FI_Chk_CIN1_Frequency(void)
{
	return TIM13_CH1_IC1_Active;
}

/*******************************************************************************
 * Function Name  : FI_Get_CINx_Frequency
 * Description    : This function return hertz from selected CINx
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CINx_Frequency(int idx)
{
	switch(idx)
	{
	case 0:
		return CIN1_Hz;
 		break;
 	case 1:
 		return CIN2_Hz;
 		break;
 	case 2:
 		return CIN3_Hz;
 		break;
 	case 3:
 		return CIN4_Hz;
 		break;
 	case 4:
 		return CIN5_Hz;
 		break;
    case 5:
        return CIN6_Hz;
        break;
 	}

	return 0;
}

/*******************************************************************************
 * Function Name  : FI_Set_CIN2_Frequency
 * Description    : This function save current frequency input from CIN2
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_CIN2_Frequency(uint32_t value)
{
	CIN2_Hz = value;
}

/*******************************************************************************
 * Function Name  : FI_Get_CIN2_Frequency
 * Description    : This function return actual hertz value from CIN2
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CIN2_Frequency(void)
{
	return CIN2_Hz;
}
/*******************************************************************************
 * Function Name  : FI_Mon_CIN2_Frequency
 * Description    : This function reset flag to check frequency input feed CIN2
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Mon_CIN2_Frequency(void)
{
	TIM14_CH1_IC1_Active = 0;
}
/*******************************************************************************
 * Function Name  : FI_Chk_CIN2_Frequency
 * Description    : This function check flag frequency input feed CIN2
 * Input          : None
 * Output         : Input feeding running
 * Return         : None
 *******************************************************************************/
uint8_t FI_Chk_CIN2_Frequency(void)
{
	return TIM14_CH1_IC1_Active;
}
/*******************************************************************************
 * Function Name  : FI_Set_CIN3_Frequency
 * Description    : This function save current frequency input from CIN3
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_CIN3_Frequency(uint32_t value)
{
	CIN3_Hz = value;
}
/*******************************************************************************
 * Function Name  : FI_Get_CIN3_Frequency
 * Description    : This function return actual hertz value from CIN3
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CIN3_Frequency(void)
{
	return CIN3_Hz;
}
/*******************************************************************************
 * Function Name  : FI_Mon_CIN3_Frequency
 * Description    : This function reset flag to check frequency input feed CIN3
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Mon_CIN3_Frequency(void)
{
	TIM2_CH2_IC2_Active = 0;
}
/*******************************************************************************
 * Function Name  : FI_Chk_CIN3_Frequency
 * Description    : This function check flag frequency input feed CIN3
 * Input          : None
 * Output         : Input feeding running
 * Return         : None
 *******************************************************************************/
uint8_t FI_Chk_CIN3_Frequency(void)
{
	return TIM2_CH2_IC2_Active;
}

/*******************************************************************************
 * Function Name  : FI_Set_CIN4_Frequency
 * Description    : This function save current frequency input from CIN4
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_CIN4_Frequency(uint32_t value)
{
	CIN4_Hz = value;
}

/*******************************************************************************
 * Function Name  : FI_Get_CIN4_Frequency
 * Description    : This function return actual hertz value from CIN4
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CIN4_Frequency(void)
{
	return CIN4_Hz;
}
/*******************************************************************************
 * Function Name  : FI_Mon_CIN4_Frequency
 * Description    : This function reset flag to check frequency input feed CIN4
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Mon_CIN4_Frequency(void)
{
	TIM2_CH1_IC1_Active = 0;
}
/*******************************************************************************
 * Function Name  : FI_Chk_CIN4_Frequency
 * Description    : This function check flag frequency input feed CIN4
 * Input          : None
 * Output         : Input feeding running
 * Return         : None
 *******************************************************************************/
uint8_t FI_Chk_CIN4_Frequency(void)
{
	return TIM2_CH1_IC1_Active;
}
/*******************************************************************************
 * Function Name  : FI_Set_CIN5_Frequency
 * Description    : This function save current frequency input from CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_CIN5_Frequency(uint32_t value)
{
	CIN5_Hz = value;
}

/*******************************************************************************
 * Function Name  : FI_Get_CIN5_Frequency
 * Description    : This function return actual hertz value from CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CIN5_Frequency(void)
{
	return CIN5_Hz;
}

/*******************************************************************************
 * Function Name  : FI_Mon_CIN5_Frequency
 * Description    : This function reset flag to check frequency input feed CIN5
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Mon_CIN5_Frequency(void)
{
	TIM3_CH2_IC1_Active = 0;
}

/*******************************************************************************
 * Function Name  : FI_Chk_CIN5_Frequency
 * Description    : This function check flag frequency input feed CIN5
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint8_t FI_Chk_CIN5_Frequency(void)
{
	return TIM3_CH2_IC1_Active;
}
/*******************************************************************************
 * Function Name  : Freq_Set_CIN_VFQ_Freq
 * Description    : This function save current frequency input from CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_CIN6_Frequency(uint32_t value)
{
	CIN6_Hz = value;
}

/*******************************************************************************
 * Function Name  : Get_CIN_VFQ_Hz_Value
 * Description    : This function return actual hertz value from CIN1
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_CIN6_Frequency(void)
{
	return CIN6_Hz;
}
/*******************************************************************************
 * Function Name  : FI_Mon_CIN6_Frequency
 * Description    : This function reset flag to check frequency input feed CIN6
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Mon_CIN6_Frequency(void)
{
	TIM3_CH2_IC2_Active = 0;
}
/*******************************************************************************
 * Function Name  : FI_Chk_CIN6_Frequency
 * Description    : This function check flag frequency input feed CIN6
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint8_t FI_Chk_CIN6_Frequency(void)
{
	return TIM3_CH2_IC2_Active;
}
/*******************************************************************************
 * Function Name  : FI_Set_VhConfig
 * Description    : This function pass cluster type
 * Input          : Cluster Type
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_VhConfig(uint8_t value)
{
	vhConfigCluster =value;
}
/*******************************************************************************
 * Function Name  : Freq_Set_DIN_PWM_Freq
 * Description    : This function save current frequency input on CCP5
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_DIN_PWM_Freq(uint32_t value)
{
	DIN2_PWM_Hz = value;
}

/*******************************************************************************
 * Function Name  : Get_DIN_PWM_Hz_Value
 * Description    : This function return actual hertz value under DIN_PWM
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint32_t FI_Get_DIN_PWM_Freq(void)
{
	return DIN2_PWM_Hz;
}

/*******************************************************************************
 * Function Name  : Set_PWM_Config
 * Description    :
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
void FI_Set_PWM_Config(uint32_t period, uint32_t pulse_width)
{
	// Backlight controlled by PWM  DI
	// Calculate duty cycle
	pulse_width *= 100;
	FI_DIN2_PWM_DutyCycle = pulse_width/period;

	// Invert signal
	FI_DIN2_PWM_DutyCycle = 100 - FI_DIN2_PWM_DutyCycle;
}

/*******************************************************************************
 * Function Name  : Get_PWM_DutyCycle
 * Description    : This function return actual hertz value
 * Input          : None
 * Output         : None
 * Return         : None
 *******************************************************************************/
uint8_t FI_Get_DIN_PWM_DutyCycle(void)
{
	return FI_DIN2_PWM_DutyCycle;
}

void FreqAI_Start(int idx)
{
	/* USER CODE BEGIN TIM2_Init 2 */
	/*##-3- Start the Input Capture in interrupt mode ##########################*/
	switch(idx)
	{
	case 1:
		if(HAL_TIM_IC_Start_IT(pv.htim13,TIM_CHANNEL_1) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}

		/* Start timer base time */
		if (HAL_TIM_Base_Start_IT(pv.htim13) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
		break;

	case 2:
		if(HAL_TIM_IC_Start_IT(pv.htim14,TIM_CHANNEL_1) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
		break;

	case 4:
		if(HAL_TIM_IC_Start_IT(pv.htim2,TIM_CHANNEL_1) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
#if 0
		/* Start timer base time */
		if (HAL_TIM_Base_Start_IT(pv.htim2) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
#endif
		break;

	case 3:
		if(HAL_TIM_IC_Start_IT(pv.htim2,TIM_CHANNEL_2) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
		break;

	case 5:
		if(HAL_TIM_IC_Start_IT(pv.htim3,TIM_CHANNEL_2) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
		break;

	case 6:
		if(HAL_TIM_IC_Start_IT(pv.htim3,TIM_CHANNEL_3) != HAL_OK)
		{
			/* Starting Error */
			Error_Handler();
		}
		break;
	}

	/* USER CODE END TIM2_Init 2 */

}

void ResetTimers(TIM_HandleTypeDef *htim)
{
	TIM2_fq_ovf++;
	if(TIM2_fq_ovf > FQ_DOG_LIMIT)
	{
		TIM2_CH1_IC1_Value1 = 0;
		TIM2_CH1_IC1_Value2 = 0;
		TIM2_fq_ovf = 0;
		TIM2_CH1_IC1_freq = 0;

		// Save frequency value to the freq module
		FI_Set_CIN4_Frequency(TIM2_CH1_IC1_freq);

		/* ITZ Identifies if its Point A or B, formula will be "(B+(OVF*0xFFFF)-A) = C",
		 * it will always be positive. must never be zero.
		 */
		TIM2_CH1_fq_capture_flag = 0;
	}

	// After N overflows set the frequency to 0 - freq is too low
	TIM2_fq_ovf2++;
	if(TIM2_fq_ovf2 > FQ_DOG_LIMIT)
	{
		TIM2_CH2_IC2_Value1 = 0;
		TIM2_CH2_IC2_Value2 = 0;
		TIM2_fq_ovf2 = 0;
		TIM2_CH2_IC2_freq = 0;

		// Save frequency value to the freq module
		FI_Set_CIN3_Frequency(TIM2_CH2_IC2_freq);
		TIM2_CH2_fq_capture_flag = 0;
	}

	TIM3_fq_ovf++;
	if(TIM3_fq_ovf > FQ_DOG_LIMIT)
	{
		TIM3_CH2_IC1_Value1 = 0;
		TIM3_CH2_IC1_Value2 = 0;
		TIM3_fq_ovf = 0;
		TIM3_CH2_IC1_freq = 0;

		// Save frequency value to the freq module
		FI_Set_CIN5_Frequency(TIM3_CH2_IC1_freq);

		/*	ITZ Identifies if its Point A or B, formula will be "(B+(OVF*0xFFFF)-A) = C " ,
		 * it will always be positive. must never be zero.
		 */
		TIM3_CH2_fq_capture_flag = 0;
	}

	// After N overflows set the frequency to 0 - freq is too low
	TIM3_fq_ovf2++;
	if(TIM3_fq_ovf2 > FQ_DOG_LIMIT)
	{
		TIM3_CH3_IC2_Value1 = 0;
		TIM3_CH3_IC2_Value2 = 0;
		TIM3_fq_ovf2 = 0;
		TIM3_CH3_IC2_freq = 0;

		// Save frequency value to the freq module
		FI_Set_CIN6_Frequency(TIM3_CH3_IC2_freq);

		TIM3_CH3_fq_capture_flag = 0;
	}

	TIM13_fq_ovf++;
	if(TIM13_fq_ovf > FQ_DOG_LIMIT)
	{
#if 1
		if ((gindex + 1) % 2)
		{
			capturetim[gindex] = 0;
			gindex--;
		}
#endif
		TIM13_CH1_IC1_Value1 = 0;
		TIM13_CH1_IC1_Value2 = 0;
		TIM13_fq_ovf = 0;
		TIM13_CH1_IC1_freq = 0;

		// Save frequency value to the freq module
		FI_Set_CIN1_Frequency(TIM13_CH1_IC1_freq);

		/* ITZ Identifies if its Point A or B, formula will be "(B+(OVF*0xFFFF)-A) = C",
		 * it will always be positive. must never be zero.
		 */
		TIM13_CH1_fq_capture_flag = 0;
	}

	TIM14_fq_ovf++;
	if(TIM14_fq_ovf > FQ_DOG_LIMIT)
	{
		TIM14_CH1_IC1_Value1 = 0;
		TIM14_CH1_IC1_Value2 = 0;
		TIM14_fq_ovf = 0;
		TIM14_CH1_IC1_freq = 0;

		// Save frequency value to the freq module
		FI_Set_CIN2_Frequency(TIM14_CH1_IC1_freq);

		/* ITZ Identifies if its Point A or B, formula will be "(B+(OVF*0xFFFF)-A) = C",
		 * it will always be positive. must never be zero.
		 */
		TIM14_CH1_fq_capture_flag = 0;
	}
}

/**
  * @brief  Conversion complete callback in non blocking mode
  * @param  htim : hadc handle
  * @retval None
  */
void HAL_TIM_IC_CaptureCallback(TIM_HandleTypeDef *htim)
{
	/*	Frequency input	*/
	/*	Input is captured - read result	*/
	if(htim->Instance == TIM3)
	{
		if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_2)
		{
			// Configurable input 1 --------------------------------------------------
			if(TIM3_CH2_fq_capture_flag == 0)
			{
				TIM3_fq_ovf = 0;  // Free running counter
				/* Get the 1st Input Capture value */
				TIM3_CH2_IC1_Value1 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_2);
				TIM3_CH2_fq_capture_flag = 1;
			}
			else if(TIM3_CH2_fq_capture_flag == 1)
			{
				/* Get the 2nd Input Capture value */
				TIM3_CH2_IC1_Value2 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_2);
				// ( ( B + (OVF*0xFFFF) ) - A ) = C
				// Expand point B to a 32 bit capture. (instead of hardware 16 bit only).

				if (TIM3_CH2_IC1_Value2 > TIM3_CH2_IC1_Value1)
				{
					TIM3_CH2_DiffCapture = TIM3_CH2_IC1_Value2 - TIM3_CH2_IC1_Value1;
				}
				else if (TIM3_CH2_IC1_Value2 < TIM3_CH2_IC1_Value1)
				{
					TIM3_CH2_DiffCapture = ((PERIOD_TIM_3 - TIM3_CH2_IC1_Value1) + TIM3_CH2_IC1_Value2);
				}

				// IC1_capture should always be positive and never zero,
				// This trap is to avoid zero division.
				if(TIM3_CH2_DiffCapture > 0)
				{
					// Calculate frequency input using the captured period //FOC 9-30-2022
					//Freq=2*10**RCC/(PSC+1)/(ARR+1)
					//2  : Period divided by 2
					//10 : Freq resolution to ~ 0.3Hz (multiplied by 10 so 10.3Hz is 103)
					//RCC: PC Clock Frequency
					//PSC: Prescaler value
					//ARR: Period captured
					TIM3_CH2_IC1_freq=10*(2*HAL_RCC_GetPCLK2Freq())/(pv.htim3->Init.Prescaler+1)/(TIM3_CH2_DiffCapture+1);
                  	TIM3_CH2_IC1_Active=1; //Turn on timer counting flag
					// Frequencies above 9 Hz are taken
					if(TIM3_CH2_IC1_freq >=9)
					{
						// save frequency value to the freq module
						FI_Set_CIN5_Frequency(TIM3_CH2_IC1_freq);
					}
					else
					{
						// Lower frequencies are discarded < 9Hz, read as 0
						FI_Set_CIN5_Frequency(0);
					}
				}
				TIM3_fq_ovf = 0;              // Free Running Counter
				TIM3_CH2_fq_capture_flag = 0; // Capture Point A on next edge.
			}
		}
		else if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_3)
		{
			// Configurable input 2 --------------------------------------------------
			if(TIM3_CH3_fq_capture_flag == 0)
			{
				TIM3_fq_ovf2 = 0;  // Free running counter
				/* Get the 1st Input Capture value */
				TIM3_CH3_IC2_Value1 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_3);
				TIM3_CH3_fq_capture_flag = 1;
			}
			else if(TIM3_CH3_fq_capture_flag == 1)
			{
				/* Get the 2nd Input Capture value */
				TIM3_CH3_IC2_Value2 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_3);
				// ( ( B + (OVF*0xFFFF) ) - A ) = C
				// Expand point B to a 32 bit capture. (instead of hardware 16 bit only).Point A is fine at 16 bit.

				if (TIM3_CH3_IC2_Value2 > TIM3_CH3_IC2_Value1)
				{
					TIM3_CH3_DiffCapture = TIM3_CH3_IC2_Value2 - TIM3_CH3_IC2_Value1;
				}
				else if (TIM3_CH3_IC2_Value2 < TIM3_CH3_IC2_Value1)
				{
					TIM3_CH3_DiffCapture = ((PERIOD_TIM_3 - TIM3_CH3_IC2_Value1) + TIM3_CH3_IC2_Value2);
				}

				// IC1_capture should always be positive and never zero,
				// This trap is to avoid zero division.
				if(TIM3_CH3_DiffCapture > 0)
				{
					// Calculate frequency input using the captured period
					//Freq=2*10**RCC/(PSC+1)/(ARR+1)
					//2  : Period divided by 2
					//10 : Freq resolution to ~ 0.3Hz (multiplied by 10 so 10.3Hz is 103)
					//RCC: PC Clock Frequency
					//PSC: Prescaler value
					//ARR: Period captured
					TIM3_CH3_IC2_freq=10*(2*HAL_RCC_GetPCLK2Freq())/(pv.htim3->Init.Prescaler+1)/(TIM3_CH3_DiffCapture+1);
					TIM3_CH2_IC2_Active=1;
					// Frequencies above 9 Hz are taken
					if(TIM3_CH3_IC2_freq >= 9)
					{
						// save frequency value to the freq module
						FI_Set_CIN6_Frequency(TIM3_CH3_IC2_freq);
					}
					else
					{
						// Lower frequencies are discarded < 9Hz, read as 0
						FI_Set_CIN6_Frequency(0);
					}
				}
				TIM3_fq_ovf2 = 0; // Free Running Counter
				TIM3_CH3_fq_capture_flag = 0; // Capture Point A on next edge.
			}
		}
	}
	else if(htim->Instance == TIM2)
	{
		if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_1)
		{
			// Configurable input 1 --------------------------------------------------
			if(TIM2_CH1_fq_capture_flag == 0)
			{
				TIM2_fq_ovf = 0;  // Free running counter
				/* Get the 1st Input Capture value */
				TIM2_CH1_IC1_Value1 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_1);
				TIM2_CH1_fq_capture_flag = 1;
			}
			else if(TIM2_CH1_fq_capture_flag == 1)
			{
				/* Get the 2nd Input Capture value */
				TIM2_CH1_IC1_Value2 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_1);
				// ( ( B + (OVF*0xFFFF) ) - A ) = C
				// Expand point B to a 32 bit capture. (instead of hardware 16 bit only).
				if (TIM2_CH1_IC1_Value2 > TIM2_CH1_IC1_Value1)
				{
					TIM2_CH1_DiffCapture = TIM2_CH1_IC1_Value2 - TIM2_CH1_IC1_Value1;
				}
				else if (TIM2_CH1_IC1_Value2 < TIM2_CH1_IC1_Value1)
				{
					TIM2_CH1_DiffCapture = ((PERIOD_TIM_2 - TIM2_CH1_IC1_Value1) + TIM2_CH1_IC1_Value2) ;
				}

				// IC1_capture should always be positive and never zero,
				// This trap is to avoid zero division.
				if(TIM2_CH1_DiffCapture > 0)
				{
					// Calculate frequency input using the captured period //FOC 9-30-2022
					//Freq=2*10**RCC/(PSC+1)/(ARR+1)
					//2  : Period divided by 2
					//10 : Freq resolution to ~ 0.3Hz (multiplied by 10 so 10.3Hz is 103)
					//RCC: PC Clock Frequency
					//PSC: Prescaler value
					//ARR: Period captured
					TIM2_CH1_IC1_freq = 10*(2*HAL_RCC_GetPCLK2Freq())/(pv.htim2->Init.Prescaler+1)/(TIM2_CH1_DiffCapture+1);
					TIM2_CH1_IC1_Active=1; //Turn on timer counting flag
					// Frequencies above 9 Hz are taken
					if(TIM2_CH1_IC1_freq >=9)
					{
						// save frequency value to the freq module
						FI_Set_CIN4_Frequency(TIM2_CH1_IC1_freq);
					}
					else
					{
						// Lower frequencies are discarded < 25Hz, read as 0
						FI_Set_CIN4_Frequency(0);
					}
				}
				TIM2_fq_ovf = 0; // Free Running Counter
				TIM2_CH1_fq_capture_flag = 0; // Capture Point A on next edge.
			}
		}
		else if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_2)
		{
			// Configurable input 2 --------------------------------------------------
			if(TIM2_CH2_fq_capture_flag == 0)
			{
				TIM2_fq_ovf2 = 0;  // Free running counter
				/* Get the 1st Input Capture value */
				TIM2_CH2_IC2_Value1 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_2);
				TIM2_CH2_fq_capture_flag = 1;
			}
			else if(TIM2_CH2_fq_capture_flag == 1)
			{
				/* Get the 2nd Input Capture value */
				TIM2_CH2_IC2_Value2 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_2);

				if (TIM2_CH2_IC2_Value2 > TIM2_CH2_IC2_Value1)
				{
					TIM2_CH2_DiffCapture = TIM2_CH2_IC2_Value2 - TIM2_CH2_IC2_Value1;
				}
				else if (TIM2_CH2_IC2_Value2 < TIM2_CH2_IC2_Value1)
				{
					TIM2_CH2_DiffCapture = ((PERIOD_TIM_2 - TIM2_CH2_IC2_Value1) + TIM2_CH2_IC2_Value2);
				}

				// IC1_capture should always be positive and never zero,
				// This trap is to avoid zero division.
				if(TIM2_CH2_DiffCapture > 0)
				{
					// Calculate frequency input using the captured period
					//Freq=2*10**RCC/(PSC+1)/(ARR+1)
					//2  : Period divided by 2
					//10 : Freq resolution to ~ 0.3Hz (multiplied by 10 so 10.3Hz is 103)
					//RCC: PC Clock Frequency
					//PSC: Prescaler value
					//ARR: Period captured
					TIM2_CH2_IC2_freq =10*(2*HAL_RCC_GetPCLK2Freq())/(pv.htim2->Init.Prescaler+1)/(TIM2_CH2_DiffCapture+1);
					TIM2_CH2_IC2_Active=1;
					// Frequencies above 9 Hz are taken
					if(TIM2_CH2_IC2_freq >= 9)
					{
						// save frequency value to the freq module
						FI_Set_CIN3_Frequency(TIM2_CH2_IC2_freq);
					}
					else
					{
						// Lower frequencies are discarded < 25Hz, read as 0
						FI_Set_CIN3_Frequency(0);
					}
				}

				TIM2_fq_ovf2 = 0; // Free Running Counter
				TIM2_CH2_fq_capture_flag = 0; // Capture Point A on next edge.
			}
		}
	}
	else if(htim->Instance == TIM13)
	{
		if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_1)
		{
			// Configurable input 1 --------------------------------------------------
			if(TIM13_CH1_fq_capture_flag == 0)
			{
				TIM13_fq_ovf = 0;  // Free running counter
				/* Get the 1st Input Capture value */
				TIM13_CH1_IC1_Value1 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_1);
				TIM13_CH1_fq_capture_flag = 1;
			}
			else if(TIM13_CH1_fq_capture_flag == 1)
			{
				/* Get the 2nd Input Capture value */
				TIM13_CH1_IC1_Value2 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_1);
				// ( ( B + (OVF*0xFFFF) ) - A ) = C
				// Expand point B to a 32 bit capture. (instead of hardware 16 bit only).Point A is fine at 16 bit.
				if (TIM13_CH1_IC1_Value2 > TIM13_CH1_IC1_Value1)
				{
					TIM13_CH1_DiffCapture = TIM13_CH1_IC1_Value2 - TIM13_CH1_IC1_Value1;
				}
				else if (TIM13_CH1_IC1_Value2 < TIM13_CH1_IC1_Value1)
				{
					TIM13_CH1_DiffCapture = ((PERIOD_TIM_13 - TIM13_CH1_IC1_Value1) + TIM13_CH1_IC1_Value2) ;
				}

				// IC1_capture should always be positive and never zero,
				// This trap is to avoid zero division.
				if(TIM13_CH1_DiffCapture > 0)
				{
					// Calculate frequency input using the captured period //FOC 9-30-2022
					//Freq=2*10**RCC/(PSC+1)/(ARR+1)
					//2  : Period divided by 2
					//10 : Freq resolution to ~ 0.3Hz (multiplied by 10 so 10.3Hz is 103)
					//RCC: PC Clock Frequency
					//PSC: Prescaler value
					//ARR: Period captured
					TIM13_CH1_IC1_freq =10*(2*HAL_RCC_GetPCLK2Freq())/(pv.htim13->Init.Prescaler+1)/(TIM13_CH1_DiffCapture+1);
					TIM13_CH1_IC1_Active=1; //Turn on timer counting flag
					// Frequencies above 9 Hz are taken
					if(TIM13_CH1_IC1_freq >=9)
					{
						// save frequency value to the freq module
						FI_Set_CIN1_Frequency(TIM13_CH1_IC1_freq);
					}
					else
					{
						// Lower frequencies are discarded < 25Hz, read as 0
						FI_Set_CIN1_Frequency(0);
					}
				}
				TIM13_fq_ovf = 0; // Free Running Counter
				TIM13_CH1_fq_capture_flag = 0; // Capture Point A on next edge.
			}

		}
	}
	else if(htim->Instance == TIM14)
	{
		if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_1)
		{
			// Configurable input 1 --------------------------------------------------
            if(TIM14_CH1_fq_capture_flag == 0)
            {
            	TIM14_fq_ovf = 0;  // Free running counter
            	/* Get the 1st Input Capture value */
            	TIM14_CH1_IC1_Value1 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_1);;
            	TIM14_CH1_fq_capture_flag = 1;
            }
            else if(TIM14_CH1_fq_capture_flag == 1)
            {
            	/* Get the 2nd Input Capture value */
            	TIM14_CH1_IC1_Value2 = HAL_TIM_ReadCapturedValue(htim, TIM_CHANNEL_1);;

            	if (TIM14_CH1_IC1_Value2 > TIM14_CH1_IC1_Value1)
            	{
            		TIM14_CH1_DiffCapture = TIM14_CH1_IC1_Value2 - TIM14_CH1_IC1_Value1;
            	}
            	else if (TIM14_CH1_IC1_Value2 < TIM14_CH1_IC1_Value1)
            	{
            		TIM14_CH1_DiffCapture = ((PERIOD_TIM_14 - TIM14_CH1_IC1_Value1) + TIM14_CH1_IC1_Value2);
            	}

            	// IC1_capture should always be positive and never zero,
            	// This trap is to avoid zero division.
            	if(TIM14_CH1_DiffCapture > 0)
            	{
            		// Calculate frequency input using the captured period
            		//Freq=2*10**RCC/(PSC+1)/(ARR+1)
            		//2  : Period divided by 2
            		//10 : Freq resolution to ~ 0.3Hz (multiplied by 10 so 10.3Hz is 103)
            		//RCC: PC Clock Frequency
            		//PSC: Prescaler value
            	    //ARR: Period captured
            		TIM14_CH1_IC1_freq =10*(2*HAL_RCC_GetPCLK2Freq())/(pv.htim14->Init.Prescaler+1)/(TIM14_CH1_DiffCapture+1);
            		TIM14_CH1_IC1_Active=1;
            		// Frequencies above 9 Hz are taken
            		if(TIM14_CH1_IC1_freq >=9)
            		{
            			// save frequency value to the freq module
            			FI_Set_CIN2_Frequency(TIM14_CH1_IC1_freq);
            		}
            		else
            		{
            			// Lower frequencies are discarded < 25Hz, read as 0
            			FI_Set_CIN2_Frequency(0);
            		}
            	}
            	TIM14_fq_ovf = 0; // Free Running Counter
            	TIM14_CH1_fq_capture_flag = 0; // Capture Point A on next edge.
            }
		}
	}
}

#endif
/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
