﻿/*
* ij1939_address.h - contains internal defines
*
* Copyright (c) 2014-2021 emotas embedded communication GmbH
*
*-------------------------------------------------------------------
* $Id: ij1939_address.h 38406 2021-10-07 13:27:37Z boe $
*
*-------------------------------------------------------------------
*
*
*
*/

/**
* \file
* \brief dataty type header
*/

#ifndef IJ1939_ADDRESS_H
#define IJ1939_ADDRESS_H 1

#define J1939_BROADCAST_ADDR	0x00ffu
#define J1939_PRIORITY_MASK		0x1c000000ul
#define J1939_SRC_ADDR_MASK		0x1c0000fful
#define J1939_DST_ADDR_MASK		0x1c00ff00ul

/* application protocol indicator 11bit-CAN-Id */
#define J1939_APPPI_MPG			0x000u	/* 000 xxxx xxxx - Multi-PG */
#define J1939_APPPI_PROPRIETARY	0x200u	/* 010 xxxx xxxx - Proprietary */


/* defines for spec parameter */
/* 0..3fff - standard PGNs */
#define J1939_RECEIVE_INTERNAL_OFFS		0x4000u
#define J1939_RECEIVE_DIAGNOSTIC_OFFS	(J1939_RECEIVE_INTERNAL_OFFS + 0x800u)
#define J1939_RECEIVE_DIAGTOOL_OFFS		(J1939_RECEIVE_INTERNAL_OFFS + 0x900u)
#define J1939_REC_SPEC_ADDR_CLAIM		(J1939_RECEIVE_INTERNAL_OFFS)

#define J1939_REC_SPEC_BAM_CONNECT		(J1939_RECEIVE_INTERNAL_OFFS + 1u)
#define J1939_REC_SPEC_BAM_DATA			(J1939_RECEIVE_INTERNAL_OFFS + 2u)

#define J1939_REC_SPEC_CMDT_CONNECT		(J1939_RECEIVE_INTERNAL_OFFS + 4u)
#define J1939_REC_SPEC_CMDT_DATA		(J1939_RECEIVE_INTERNAL_OFFS + 5u)

#define J1939_REC_SPEC_REQUEST			(J1939_RECEIVE_INTERNAL_OFFS + 7u)
#define J1939_REC_SPEC_NMEA_GROUP		(J1939_RECEIVE_INTERNAL_OFFS + 8u)
#define J1939_TR_SPEC_SAFETY_SHM		(J1939_RECEIVE_INTERNAL_OFFS + 9u)
#define J1939_TR_SPEC_SAFETY_SDM		(J1939_RECEIVE_INTERNAL_OFFS + 10u)
#define J1939_REC_SPEC_SAFETY_SHM		(J1939_RECEIVE_INTERNAL_OFFS + 11u)
#define J1939_REC_SPEC_SAFETY_SDM		(J1939_RECEIVE_INTERNAL_OFFS + 12u)
#define J1939_REC_SPEC_ACKM				(J1939_RECEIVE_INTERNAL_OFFS + 13u)
#define J1939_REC_SPEC_RVC				(J1939_RECEIVE_INTERNAL_OFFS + 14u)

#define J1939_REC_SPEC_MULTI_PG_29BIT	(J1939_RECEIVE_INTERNAL_OFFS + 15u)
#define J1939_REC_SPEC_MULTI_PG_11BIT 	(J1939_RECEIVE_INTERNAL_OFFS + 16u)
#define J1939_REC_SPEC_PROPRIETARY_11BIT (J1939_RECEIVE_INTERNAL_OFFS + 17u)

#define J1939_REC_SPEC_CAM11_SRV		(J1939_RECEIVE_INTERNAL_OFFS + 20u)
#define J1939_REC_SPEC_CAM21_CLIENT		(J1939_RECEIVE_INTERNAL_OFFS + 21u)

#define J1939_USER_DISABLED		1u


/* datatypes */

/* function prototypes */

RET_T	ij1939_addressInit(CO_LINE_DECL, const J1939_PGN_CONFIG_T *devNameConfig);
UNSIGNED32 ij1939_addressCalculateCanId(UNSIGNED32 pgn,
			UNSIGNED8 nodeAddr, UNSIGNED8 priority);
UNSIGNED8 ij1939_addressGetNodeId(CO_LINE_DECL);
void	ij1939_addressClaimReceived(CO_LINE_DECL, const CO_CAN_REC_MSG_T *msg);
void	ij1939_addressCommanded(CO_LINE_DECL, const J1939_MAPPING_T *pRecMap,
			UNSIGNED8 newNode);
void	ij1939_addressSendClaimAddr(CO_LINE_DECL);
RET_T	ij1939_addressSetCob(CO_LINE_DECL, UNSIGNED32 pgn, UNSIGNED8 srcAddress,
		UNSIGNED8 priority, UNSIGNED32 addrMask,
		COB_REFERENZ_T cobRef, UNSIGNED8 len);
void	ij1939_initAddressVars(CO_LINE_DECL, UNSIGNED8	newNodeAddress);

#endif /* IJ1939_ADDRESS_H */

