﻿/*
* ij1939_tp.h - contains internal defines
*
* Copyright (c) 2014-2021 emotas embedded communication GmbH
*
*-------------------------------------------------------------------
* $Id: ij1939_tp.h 38943 2021-11-26 14:32:44Z boe $
*
*-------------------------------------------------------------------
*
*
*
*/

/**
* \file
* \brief dataty type header
*/

#ifndef IJ1939_TP_H
#define IJ1939_TP_H 1

/* datatypes */
#if defined(J1939_BAM_SUPPORTED) || defined(J1939_CMDT_SUPPORTED)
# define J1939_TP_SUPPORTED	1
#endif /* defined(J1939_BAM_SUPPORTED) || defined(J1939_CMDT_SUPPORTED) */


typedef struct {
	UNSIGNED8	sessionNr;
	UNSIGNED32	totalNrOfSegments;	/* total number of segments (only data!) */
	UNSIGNED32	totalMsgSize;		/* total number of bytes (only data */
	UNSIGNED32	curSegmentNr;		/* current segment number */
	UNSIGNED32	curMsgSize;			/* current message size */
	UNSIGNED8   maxSegmentCnt;
	const J1939_PGN_CONFIG_T *pCfg;
	UNSIGNED8	abortReason;
} TP_SESSION_T;


/* tp command management (CC) */
#define J1939_TP_CM_RTS			16u	
#define J1939_TP_CM_CTS			17u	
#define J1939_TP_CM_ACK			19u	
#define J1939_TP_CM_BAM			32u
#define J1939_TP_CM_ABORT		255u	

/* tp command management (FD) */
#define J1939_FD_TP_CM_RTS		0u	
#define J1939_FD_TP_CM_CTS		1u	
#define J1939_FD_TP_CM_EOMS		2u	
#define J1939_FD_TP_CM_ACK		3u
#define J1939_FD_TP_CM_BAM		4u
#define J1939_FD_TP_CM_ABORT	15u	
#define J1939_FD_TP_CM_MASK		0x0fu	


/* function prototypes */

RET_T	ij1939_tpInit(CO_LINE_DECL);
RET_T	ij1939_tpUpdateCob(CO_LINE_DECL, UNSIGNED8 nodeAddress);
RET_T	ij1939_tpUpdateRecTpCob(CO_LINE_DECL, UNSIGNED8 remoteAddress);
RET_T	ij1939_tpUpdateTrTpCob(CO_LINE_DECL, UNSIGNED8 dstAddress);

RET_T	ij1939_tpSendConnect(CO_LINE_DECL, UNSIGNED8 dstAddr, UNSIGNED8 ctrlByte,
			const TP_SESSION_T *pTp);
RET_T	ij1939_tpSendData(CO_LINE_DECL, UNSIGNED8 dstAddr,
			const UNSIGNED8 trData[], UNSIGNED8 dataLen, UNSIGNED8 flags);

void	ij1939_tpConnectReceived(CO_LINE_DECL, const CO_CAN_REC_MSG_T *pMsg);
void	ij1939_tpDataReceived(CO_LINE_DECL, const CO_CAN_REC_MSG_T *pMsg);
void	ij1939_tpSendAnswer(CO_LINE_DECL, UNSIGNED8 dstAddr, UNSIGNED8 trData[],			UNSIGNED8 dataLen);

UNSIGNED32 ij1939_tpUnmap3Value(const UNSIGNED8	src[]);
void ij1939_tpMap3Value(UNSIGNED8 dst[], UNSIGNED32 data);
UNSIGNED16 ij1939_tpUnmap2Value(const UNSIGNED8	src[]);
void ij1939_tpMap2Value(UNSIGNED8 dst[], UNSIGNED16 data);

RET_T ij1939_tpConnectEndOfMsgStatus(CO_LINE_DECL, const TP_SESSION_T *pTp,
			const CO_CAN_REC_MSG_T *pMsg);
void ij1939_tpRecSendAnswer(CO_LINE_DECL, UNSIGNED8 dstAddr,
			const UNSIGNED8 trData[], UNSIGNED8 dataLen);


#endif /* IJ1939_TP_H */

