#include <gui/scr_io_screen/SCR_IOView.hpp>
#include <touchgfx/Color.hpp>
#include "stm32h7xx_hal.h"
#include "../../../../Core/Maximatecc/user_modify_files/User_Define.h"
#include <BitmapdataBase.hpp>

#define LCD_BRT_MAX 		100
#define LCD_BRT_MIN 		0

SCR_IOView::SCR_IOView()
{
	key_position = 1;
	brightness_value = 0;

	cur_di_state = 1;
	cur_res      = 1;
	cur_Freq     = 1;
	current      = 1;

#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
	Get_DL(DIGITAL_OUTPUT_01_CFG, &dio_cfg);

	Get_DL(DIGITAL_OUTPUT_01_STATE, &state);

	if(dio_cfg == CONF_HIGH_SIDE_DRIVER)
	{
		TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
		TBT_HighSide.invalidate();

		/* DESelect the Keypad button */
		TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
		TBT_LowSide.invalidate();
	}
	else
	if(dio_cfg == CONF_LOW_SIDE_DRIVER)
	{
		/* Select the Keypad button */
		TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
		TBT_LowSide.invalidate();

		/* DESelect the Keypad button */
		TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
		TBT_HighSide.invalidate();
	}
	else
	if(dio_cfg == CONF_OPEN_DRIVE_DRIVER)
	{
		/* DESelect the Keypad button */
		TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
		TBT_HighSide.invalidate();

		/* DESelect the Keypad button */
		TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
		TBT_LowSide.invalidate();
	}
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
	/* Get the LCD Brightness value from the DB */
	Get_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
#endif
	/* Update Brihtness value */
	slider1.setValue(brightness_value);

	/* DESelect the Keypad button */
	TXT_HighSide.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
	TXT_HighSide.invalidate();
}

void SCR_IOView::setupScreen()
{
    SCR_IOViewBase::setupScreen();
}

void SCR_IOView::tearDownScreen()
{
    SCR_IOViewBase::tearDownScreen();
}

void SCR_IOView::keyUpdate(uint8_t val)
{
	uint32_t position = key_position;

	if((KEY1_SHORT_PRESS == val) || (KEY1_LONG_PRESS == val))
		movePrevious();
	else
	if(KEY2_SHORT_PRESS == val)
	{
		switch(position)
		{
			case 1:
#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
				if(state == CONF_DIGITAL_OUTPUT_OFF)
				{
					TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
					TBT_HighSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_ON;
				}
				else
				if(state == CONF_DIGITAL_OUTPUT_ON)
				{
					/* DESelect the Keypad button */
					TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
					TBT_HighSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_OFF;
				}
#endif
				break;

			case 2:
#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
				if(state == CONF_DIGITAL_OUTPUT_OFF)
				{
					TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
					TBT_LowSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_ON;
				}
				else
				if(state == CONF_DIGITAL_OUTPUT_ON)
				{
					/* DESelect the Keypad button */
					TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
					TBT_LowSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_OFF;
				}
#endif
				break;

			case 3:
#if (SDK_SERVICE_LCD == PS_ENABLE)
				brightness_value--;
				if (!(LCD_BRT_MIN <= brightness_value))
					brightness_value = LCD_BRT_MIN;

				Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);

				if (LCD_BRT_MIN == brightness_value)
					slider1.setValue(brightness_value);
				else
					slider1.setValue(brightness_value);
#endif
				break;

			case 5:
				if ((cur_di_state > 1) && (cur_di_state <= 5))
				{
					cur_di_state--;
					Unicode::snprintf(DI_STATEBuffer, DI_STATE_SIZE, "%d" , cur_di_state);
				}
				DI_STATE.invalidate();
				break;

			case 6:
				if ((cur_res > 1) && (cur_res <= 6))
				{
					cur_res--;
					Unicode::snprintf(RES_VALBuffer, RES_VAL_SIZE, "%d" , cur_res);
				}
				RES_VAL.invalidate();
				break;

			case 7:
				if ((cur_Freq > 1) && (cur_Freq <= 6))
				{
					cur_Freq--;
					Unicode::snprintf(FREQ_VALBuffer, FREQ_VAL_SIZE, "%d" , cur_Freq);
				}
				FREQ_VAL.invalidate();
				break;
		}
	}
	else
	if(KEY2_LONG_PRESS == val)
	{
		key_position++;

		if (9 == key_position)
			key_position = 1;

		switch(key_position)
		{
			case 1:

				/* DESelect the Keypad button */
				textArea13.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				textArea13.invalidate();

				/* DESelect the Keypad button */
				TXT_HighSide.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				TXT_HighSide.invalidate();
				break;

			case 2:

				/* DESelect the Keypad button */
				TXT_HighSide.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				TXT_HighSide.invalidate();

				/* DESelect the Keypad button */
				TXT_LowSide.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				TXT_LowSide.invalidate();
				break;

			case 3:

				/* DESelect the Keypad button */
				TXT_LowSide.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				TXT_LowSide.invalidate();

				/* DESelect the Keypad button */
				textArea16.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				textArea16.invalidate();
				break;

			case 4:

				/* DESelect the Keypad button */
				textArea16.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				textArea16.invalidate();

				/* DESelect the Keypad button */
				textArea17.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				textArea17.invalidate();
				break;

			case 5:

				/* DESelect the Keypad button */
				textArea17.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				textArea17.invalidate();

				/* DESelect the Keypad button */
				textArea5.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				textArea5.invalidate();
				break;

			case 6:

				/* DESelect the Keypad button */
				textArea5.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				textArea5.invalidate();

				/* DESelect the Keypad button */
				textArea9.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				textArea9.invalidate();
				break;

			case 7:

				/* DESelect the Keypad button */
				textArea9.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				textArea9.invalidate();

				/* DESelect the Keypad button */
				textArea6.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				textArea6.invalidate();
				break;

			case 8:

				/* DESelect the Keypad button */
				textArea6.setColor(touchgfx::Color::getColorFromRGB(0, 0, 0));
				textArea6.invalidate();

				/* DESelect the Keypad button */
				textArea13.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
				textArea13.invalidate();
				break;

			default:
				break;
		}
	}
	else
	if(KEY3_SHORT_PRESS == val)
	{
		switch(position)
		{
			case 1:
#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
				if(state == CONF_DIGITAL_OUTPUT_OFF)
				{
					TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
					TBT_HighSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_ON;
				}
				else
				if(state == CONF_DIGITAL_OUTPUT_ON)
				{
					/* DESelect the Keypad button */
					TBT_HighSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
					TBT_HighSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_OFF;
				}
#endif
				break;

			case 2:
#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
				if(state == CONF_DIGITAL_OUTPUT_OFF)
				{
					TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
					TBT_LowSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_ON;
				}
				else
				if(state == CONF_DIGITAL_OUTPUT_ON)
				{
					/* DESelect the Keypad button */
					TBT_LowSide.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
					TBT_LowSide.invalidate();
					state = CONF_DIGITAL_OUTPUT_OFF;
				}
#endif
				break;

			case 3:
#if (SDK_SERVICE_LCD == PS_ENABLE)
				brightness_value++;
				if (!(LCD_BRT_MAX >= brightness_value))
					brightness_value = LCD_BRT_MAX;

				Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
				if (LCD_BRT_MAX == brightness_value)
					slider1.setValue(brightness_value);
				else
					slider1.setValue(brightness_value);
#endif
				break;

			case 5:
				if ((cur_di_state > 0) && (cur_di_state < 5))
				{
					cur_di_state++;
					Unicode::snprintf(DI_STATEBuffer, DI_STATE_SIZE, "%d" , cur_di_state);
				}
				DI_STATE.invalidate();
				break;

			case 6:
				if ((cur_res > 0) && (cur_res < 6))
				{
					cur_res++;
					Unicode::snprintf(RES_VALBuffer, RES_VAL_SIZE, "%d" , cur_res);
				}
				RES_VAL.invalidate();
				break;

			case 7:
				if ((cur_Freq > 0) && (cur_Freq < 5))
				{
					cur_Freq++;
					Unicode::snprintf(FREQ_VALBuffer, FREQ_VAL_SIZE, "%d" , cur_Freq);
				}
				FREQ_VAL.invalidate();
				break;
		}
	}
	else
	if(KEY3_LONG_PRESS == val)
	{
		switch(position)
		{
			case 1:
#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
				if(state == CONF_DIGITAL_OUTPUT_OFF)
				{
					Set_DL(DIGITAL_OUTPUT_01_STATE, &state);
				}
				else
				if(state == CONF_DIGITAL_OUTPUT_ON)
				{
					state = CONF_HIGH_SIDE_DRIVER;
					Set_DL(DIGITAL_OUTPUT_01_CFG, &state);

					state = CONF_DIGITAL_OUTPUT_ON;
					Set_DL(DIGITAL_OUTPUT_01_STATE, &state);
				}
#endif
				break;

			case 2:
#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
				if(state == CONF_DIGITAL_OUTPUT_OFF)
				{
					Set_DL(DIGITAL_OUTPUT_01_STATE, &state);
				}
				else
				if(state == CONF_DIGITAL_OUTPUT_ON)
				{
					state = CONF_LOW_SIDE_DRIVER;
					Set_DL(DIGITAL_OUTPUT_01_CFG, &state);

					state = CONF_DIGITAL_OUTPUT_ON;
					Set_DL(DIGITAL_OUTPUT_01_STATE, &state);
				}
#endif
				break;

			case 5:
#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
				cfg_type = CI_DIGITAL_STB;

				if(cur_di_state == 1)
				{
					Set_DL(CFG_INPUT_01_TYPE , &cfg_type);
				}
				else
				if(cur_di_state == 2)
				{
					Set_DL(CFG_INPUT_02_TYPE , &cfg_type);
				}
				else
				if(cur_di_state == 3)
				{
					Set_DL(CFG_INPUT_03_TYPE , &cfg_type);
				}
				else
				if(cur_di_state == 4)
				{
					Set_DL(CFG_INPUT_04_TYPE , &cfg_type);
				}
				else
				if(cur_di_state == 5)
				{
					Set_DL(CFG_INPUT_05_TYPE , &cfg_type);
				}
#endif
				break;

			case 6:
#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
				cfg_type = CI_INPUT_RESISTANCE;

				if(cur_res == 1)
				{
					Set_DL(CFG_INPUT_01_TYPE , &cfg_type);
				}
				else
				if(cur_res == 2)
				{
					Set_DL(CFG_INPUT_02_TYPE , &cfg_type);
				}
				else
				if(cur_res == 3)
				{
					Set_DL(CFG_INPUT_03_TYPE , &cfg_type);
				}
				else
				if(cur_res == 4)
				{
					Set_DL(CFG_INPUT_04_TYPE , &cfg_type);
				}
				else
				if(cur_res == 5)
				{
					Set_DL(CFG_INPUT_05_TYPE , &cfg_type);
				}
#endif
				break;

			case 7:
#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
				cfg_type = CI_INPUT_FREQUENCY;

				if(cur_Freq == 1)
				{
					Set_DL(CFG_INPUT_01_TYPE , &cfg_type);
				}
				else
				if(cur_Freq == 2)
				{
					Set_DL(CFG_INPUT_02_TYPE , &cfg_type);
				}
				else
				if(cur_Freq == 3)
				{
					Set_DL(CFG_INPUT_03_TYPE , &cfg_type);
				}
				else
				if(cur_Freq == 4)
				{
					Set_DL(CFG_INPUT_04_TYPE , &cfg_type);
				}
				else
				if(cur_Freq == 5)
				{
					Set_DL(CFG_INPUT_05_TYPE , &cfg_type);
				}
#endif
				break;

			case 8:
#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
				cfg_type = CI_INPUT_CURRENT;

				Set_DL(CFG_INPUT_06_TYPE , &cfg_type);
#endif
				break;
		}
	}
	else
	if((KEY4_SHORT_PRESS == val) || (KEY4_LONG_PRESS == val))
		moveBackScreen();
}

void SCR_IOView::movePrevious()
{
	application().gotoSCR_MAINScreenNoTransition();
}

void SCR_IOView::moveBackScreen()
{

	application().gotoSCR_WLIGHTSScreenNoTransition();
}

void SCR_IOView::trigger()
{
#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
	uint32_t val = 0;

	update_val ++;

	/* Update AI1 Value */
	if (33 > update_val)
	{
		return;
	}
	update_val = 0;

	{
		switch(key_position)
		{
			case 4:
				val = 0;
				Get_DL(IGNITION_STATUS, (uint8_t*)&val);

				if(val == 1)
				{
					TBT_Ignition.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_ON_ID));
					TBT_Ignition.invalidate();
				}
				else
				if(val == 0)
				{
					TBT_Ignition.setBitmaps(touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID), touchgfx::Bitmap(BITMAP_BLUE_TOGGLEBARS_TOGGLE_RE_SMALL_BUTTON_OFF_ID));
					TBT_Ignition.invalidate();
				}
				break;

			case 5:

				if(cur_di_state == 1)
				{
					val = 0;
					Get_DL(CFG_INPUT_01_DIGITAL_STB , (uint8_t *)&val);

					if(val == 1)
					{

						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "ON");
					}
					else
					{
						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "OFF");
					}
					textArea10.invalidate();
				}
				else
				if(cur_di_state == 2)
				{
					val = 0;
					Get_DL(CFG_INPUT_02_DIGITAL_STB , (uint8_t *)&val);

					if(val == 1)
					{

						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "ON");
					}
					else
					{
						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "OFF");
					}
					textArea10.invalidate();
				}
				else
				if(cur_di_state == 3)
				{
					val = 0;
					Get_DL(CFG_INPUT_03_DIGITAL_STB , (uint8_t *)&val);

					if(val == 1)
					{

						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "ON");
					}
					else
					{
						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "OFF");
					}
					textArea10.invalidate();
				}
				else
				if(cur_di_state == 4)
				{
					val = 0;
					Get_DL(CFG_INPUT_04_DIGITAL_STB , (uint8_t *)&val);

					if(val == 1)
					{

						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "ON");
					}
					else
					{
						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "OFF");
					}
					textArea10.invalidate();
				}
				else
				if(cur_di_state == 5)
				{
					val = 0;
					Get_DL(CFG_INPUT_05_DIGITAL_STB , (uint8_t *)&val);

					if(val == 1)
					{

						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "ON");
					}
					else
					{
						Unicode::snprintf(textArea10Buffer, TEXTAREA10_SIZE, "OFF");
					}
					textArea10.invalidate();
				}

				break;

			case 6:
				if(cur_res == 1)
				{
					val = 0;
					Get_DL(CFG_INPUT_01_RESISTANCE , (uint8_t *)&val);

					Unicode::snprintf(textArea11Buffer, TEXTAREA11_SIZE, "%d" , val);
					textArea11.invalidate();
				}
				else
				if(cur_res == 2)
				{
					val = 0;
					Get_DL(CFG_INPUT_02_RESISTANCE , (uint8_t *)&val);

					Unicode::snprintf(textArea11Buffer, TEXTAREA11_SIZE, "%d" , val);
					textArea11.invalidate();
				}
				else
				if(cur_res == 3)
				{
					val = 0;
					Get_DL(CFG_INPUT_03_RESISTANCE , (uint8_t *)&val);

					Unicode::snprintf(textArea11Buffer, TEXTAREA11_SIZE, "%d" , val);
					textArea11.invalidate();
				}
				else
				if(cur_res == 4)
				{
					val = 0;
					Get_DL(CFG_INPUT_04_RESISTANCE , (uint8_t *)&val);

					Unicode::snprintf(textArea11Buffer, TEXTAREA11_SIZE, "%d" , val);
					textArea11.invalidate();
				}
				else
				if(cur_res == 5)
				{
					val = 0;
					Get_DL(CFG_INPUT_05_RESISTANCE , (uint8_t *)&val);

					Unicode::snprintf(textArea11Buffer, TEXTAREA11_SIZE, "%d" , val);
					textArea11.invalidate();
				}
				else
				/*if(cur_res == 6)
				{
					val = 0;
					Get_DL(CFG_INPUT_06_RESISTANCE , (uint8_t *)&val);

					Unicode::snprintf(textArea11Buffer, TEXTAREA11_SIZE, "%d" , val);
					textArea11.invalidate();
				}
				break;*/

			case 7:

				if(cur_Freq == 1)
				{
					val = 0;
					Get_DL(CFG_INPUT_01_FREQUENCY , (uint8_t *)&val);

					Unicode::snprintf(textArea7Buffer, TEXTAREA7_SIZE, "%d" , val);
					textArea7.invalidate();
				}
				else
				if(cur_Freq == 2)
				{
					val = 0;
					Get_DL(CFG_INPUT_02_FREQUENCY , (uint8_t *)&val);

					Unicode::snprintf(textArea7Buffer, TEXTAREA7_SIZE, "%d" , val);
					textArea7.invalidate();
				}
				else
				if(cur_Freq == 3)
				{
					val = 0;
					Get_DL(CFG_INPUT_03_FREQUENCY , (uint8_t *)&val);

					Unicode::snprintf(textArea7Buffer, TEXTAREA7_SIZE, "%d" , val);
					textArea7.invalidate();
				}
				else
				if(cur_Freq == 4)
				{
					val = 0;
					Get_DL(CFG_INPUT_04_FREQUENCY , (uint8_t *)&val);

					Unicode::snprintf(textArea7Buffer, TEXTAREA7_SIZE, "%d" , val);
					textArea7.invalidate();
				}
				else
				if(cur_Freq == 5)
				{
					val = 0;
					Get_DL(CFG_INPUT_05_FREQUENCY , (uint8_t *)&val);

					Unicode::snprintf(textArea7Buffer, TEXTAREA7_SIZE, "%d" , val);
					textArea7.invalidate();
				}
				break;

			case 8:

				if(current == 1)
				{
					val = 0;
					Get_DL(CFG_INPUT_06_CURRENT , (uint8_t *)&val);

					Unicode::snprintf(textArea14Buffer, TEXTAREA14_SIZE, "%d" , val);
					textArea14.invalidate();
				}
				break;

			default:
				break;
		}
	}
#endif
}

void SCR_IOView::watchdogstatus(uint8_t *val)
{
	*val = 0;
}
