#include <gui/scr_main_screen/SCR_MAINView.hpp>
#include <touchgfx/Color.hpp>
#include "../../../../Core/Maximatecc/user_modify_files/User_Define.h"
#include "../../../core/Maximatecc/inc/J1939.h"

#define REFRESH_TIME 			100
#define REFRESH_TIME_IN_SEC 	33

SCR_MAINView::SCR_MAINView()
{
	refresh_val = 0;
	values = 0;

	uint8_t Seconds;
	uint8_t Minutes;
	uint8_t Hours;

	key_position = 1;

#if (SDK_SERVICE_RTC == PS_ENABLE)
	/* Get the RTC DB */
	Get_DL(GET_RTC_SECOND, &Seconds);
	Get_DL(GET_RTC_MINUTE, &Minutes);
	Get_DL(GET_RTC_HOUR, &Hours);
#endif

    digitalHours = Hours;
    digitalMinutes = Minutes;
    digitalSeconds = Seconds;

    digitalClock1.invalidate();
}

void SCR_MAINView::setupScreen()
{
	refresh_val = 0;
	IMP_Voltage.getRange(imageProgress1Min, imageProgress1Max);
	circleProgress1.getRange(circleProgress1Min, circleProgress1Max);
	GAU_RPM.getRange(gauge1Min, gauge1Max);
	//SCR_MAINViewBase::setupScreen();
	voltage_mode = CI_INPUT_VOLTAGE_HIGH;
	Set_DL(CFG_INPUT_01_TYPE, &voltage_mode);
}

void SCR_MAINView::tearDownScreen()
{
    SCR_MAINViewBase::tearDownScreen();
}

void SCR_MAINView::keyUpdate(uint8_t val)
{
	if((KEY1_SHORT_PRESS == val) || (KEY1_LONG_PRESS == val))
		movePrevious();
	else
	if((KEY2_SHORT_PRESS == val) || (KEY2_LONG_PRESS == val))
		moveNext();
	else
	if((KEY3_SHORT_PRESS == val) || (KEY3_LONG_PRESS == val))
		moveNextScreen();
	else
	if((KEY4_SHORT_PRESS == val) || (KEY4_LONG_PRESS == val))
		moveBackScreen();

}

void SCR_MAINView::movePrevious()
{

}

void SCR_MAINView::moveNext()
{

}

void SCR_MAINView::moveNextScreen()
{

}

void SCR_MAINView::moveBackScreen()
{
	application().gotoSCR_IOScreenNoTransition();
}

void SCR_MAINView::trigger()
{
	uint8_t Seconds;
	uint8_t Minutes;
	uint8_t Hours;
	uint16_t gauge = 0;
	tickCounter++;

	if( 10 <= tickCounter)
	{
		tickCounter = 0;

#if (SDK_SERVICE_RTC == PS_ENABLE)
		/* Get the RTC DB */
		Get_DL(GET_RTC_SECOND, &Seconds);
		Get_DL(GET_RTC_MINUTE, &Minutes);
		Get_DL(GET_RTC_HOUR, &Hours);
#endif

		digitalHours = Hours;
		digitalMinutes = Minutes;
		digitalSeconds = Seconds;

		digitalClock1.setTime24Hour(digitalHours, digitalMinutes, digitalSeconds);

	    digitalClock1.invalidate();
	}

	uint32_t val = 0;
	refresh_val++;

	if (REFRESH_TIME_IN_SEC == refresh_val)
	{
		refresh_val = 0;

#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)
		/* Get the Light Sensor Data */
		Get_DL(LIGHT_SENSOR_DATA , (uint8_t *)&val);
		Unicode::snprintf(LTSDATABuffer, LTSDATA_SIZE, "%d", val);
		LTSDATA.invalidate();
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
		/* Set the LCD Brightness */
		if ((0 <= val) && (500 >= val) && (100 != brightness_value))
		{
			brightness_value = 100;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(100 % (circleProgress1Max + 1));
		}
		else
		if ((500 < val) && (1000 >= val) && (85 != brightness_value))
		{
			brightness_value = 85;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(85 % (circleProgress1Max + 1));
		}
		else
		if ((1000 < val) && (1500 >= val) && (70 != brightness_value))
		{
			brightness_value = 70;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(70 % (circleProgress1Max + 1));
		}
		else
		if ((1500 < val) && (2000 >= val) && (55 != brightness_value))
		{
			brightness_value = 55;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(55 % (circleProgress1Max + 1));
		}
		else
		if ((2500 < val) && (3000 >= val) && (40 != brightness_value))
		{
			brightness_value = 40;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(40 % (circleProgress1Max + 1));
		}
		else
		if ((3500 < val) && (4000 >= val) && (25 != brightness_value))
		{
			brightness_value = 25;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(25 % (circleProgress1Max + 1));
		}
		else
		if ((4200 < val) && (4500 >= val) && (15 != brightness_value))
		{
			brightness_value = 15;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(15 % (circleProgress1Max + 1));
		}
		else
		if ((4500 <= val) && (10 != brightness_value))
		{
			brightness_value = 10;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
			circleProgress1.setValue(10 % (circleProgress1Max + 1));
		}
#endif
	}
	gauge = 0;
	Get_DL(ENGINE_SPEED, (uint8_t *)&gauge);
#if (SDK_SERVICE_J1939 == PS_ENABLE)
    float fengine_sp= ConvertReadableData((uint32_t)gauge,rx_mapping_61444_ext,Engine_Speed);
	GAU_RPM.setValue((uint16_t)fengine_sp);
	Unicode::snprintf(GAUGEVALBuffer, GAUGEVAL_SIZE, "%d", (uint16_t)fengine_sp);
#endif
	GAUGEVAL.invalidate();

	gauge = 0;
	Get_DL(CFG_INPUT_01_VOLTAGE_32V, (uint8_t *)&gauge);
	gauge = gauge/1000;
	IMP_Voltage.setValue(gauge);

	Unicode::snprintf(textArea2_1Buffer, TEXTAREA2_1_SIZE, "%d", gauge);
	textArea2_1.invalidate();
}


void SCR_MAINView::handleTickEvent()
{
	values++;
	if(REFRESH_TIME == values)
	{
#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)
		values = 0;
		Get_DL(LIGHT_SENSOR_DATA , (uint8_t *)&val);
		updateProgress(val);
#endif
	}
}

void SCR_MAINView::updateProgress(uint16_t tick)
{
	//IMP_Voltage.setValue(tick % (imageProgress1Max + 1));
	//circleProgress1.setValue(tick % (circleProgress1Max + 1));
}

void SCR_MAINView::watchdogstatus(uint8_t *val)
{
	*val = 0;
}
